/* $Filename: WormWars/Source/system.h
 * $VER:      WormWars 6.9 for Amiga
 *
 *  Copyright 2002 James R. Jacobs. Freely distributable.

#INCLUDES -------------------------------------------------------------- */

#include <exec/exec.h>
#include <exec/memory.h>
#include <pragmas/exec_pragmas.h>
#include <clib/exec_protos.h>
#include <exec/execbase.h>

#include <intuition/intuition.h>
#include <intuition/gadgetclass.h>   /* STRINGA_ReplaceMode */
#include <intuition/intuitionbase.h> /* struct IntuitionBase */
#include <pragmas/intuition_pragmas.h>

// #include <pragmas/asl_pragmas.h>
#include <libraries/asl.h>           /* ASL_FileRequest */

#include <libraries/gadtools.h>      /* struct StringInfo */
#include <pragmas/gadtools_pragmas.h>

#include <devices/audio.h>
#include <devices/gameport.h>        /* struct GamePortTrigger */

// #include <pragmas/dos_pragmas.h>
#include <dos/dosextens.h>           /* struct Process */
#include <dos/dos.h>

#include <graphics/displayinfo.h>    /* PAL_MONITOR_ID, etc. */
#include <pragmas/graphics_pragmas.h>

#include <libraries/iffparse.h>
#include <pragmas/iffparse_pragmas.h>

#include <utility/date.h>            /* struct DateStamp */
#include <pragmas/utility_pragmas.h>

#include <workbench/workbench.h>     /* struct DiskObject */
#include <pragmas/wb_pragmas.h>

#include <hardware/cia.h>            /* struct CIA */

#include <libraries/lowlevel.h>

// #include <libraries/amigaguide.h>

#include <stdio.h>                   /* FILE, printf() */
#include <stdlib.h>                  /* EXIT_SUCCESS, EXIT_FAILURE */

#include "diff.h"
#include "same.h"
#include "libproto.h"

/* joysticks */

#define JOYUP          1
#define JOYDOWN        2
#define JOYLEFT        4
#define JOYRIGHT       8
#define JOYFIRE1      16
#define JOYFIRE2      32
#define POTGOR         *(UWORD *)0xDFF016     

#define OLD            1
#define NEW            0

/* #DEFINES ---------------------------------------------------------------

Help|About... window */

#define ABOUTLINES     6
#define ABOUTSHADOW    DARKGREY
#define ABOUTSHINE     LIGHTGREY
#define PROJECTX     136
#define PROJECTY      75
#define KICKSTARTX   104
#define KICKSTARTY    91
#define WORKBENCHX   104
#define WORKBENCHY    99

/* fxable/musicable */

#define FAILED         0 // tried and failed
#define SUCCEEDED      1 // tried and succeeded
#define UNTRIED        2 // untried, will try at startup
#define DEFER          3 // untried, will try when needed

/* miscellaneous */

#define DEPTH          4
#define ANIMDELAY   1800
#define TSOFFSET      92 // you can adjust y-positions of certain things by adjusting this

/* constant strings used more than once */

#define TITLEBAR       "Worm Wars 6.9"
#define PATTERN        "(#?.fset)"
#define OLDKICKSTART   "Worm Wars: You need Kickstart R2.04+!\n(Can't open intuition.library V37+!)\n"

/* object descriptions (in pixels) */

#define FIRSTDESCX   130
#define SECONDDESCX    (SCREENXPIXEL - FIRSTDESCX)
#define DESCY          3

/* ARRAYS ---------------------------------------------------------------- */

#define CREATUREHELPS 13

struct
{   UBYTE  image;
    STRPTR desc;
    ULONG  score,
           pain;
} creaturehelp[CREATUREHELPS + 1] =
{   {BIRD,      "Bird",      SCORE_BIRD,      PAIN_BIRD},
    {CLOUD,     "Cloud",     SCORE_CLOUD,     PAIN_CLOUD},
    {DOG,       "Dog",       SCORE_DOG,       PAIN_DOG},
    {FIRSTDRIP, "Drip",      SCORE_DRIP,      PAIN_DRIP},
    {FISH,      "Fish",      SCORE_FISH,      PAIN_FISH},
    {GOAT,      "Goat",      SCORE_GOAT,      PAIN_GOAT},
    {ORB,       "Orb",       SCORE_ORB,       PAIN_ORB},
    {OCTOPUS,   "Octopus",   SCORE_OCTOPUS,   PAIN_OCTOPUS},
    {OTTER,     "Otter",     SCORE_OTTER,     PAIN_OTTER},
    {PENGUIN,   "Penguin",   SCORE_PENGUIN,   PAIN_PENGUIN},
    {PROTECTOR, "Protector", 0,               PAIN_PROTECTOR},
    {SLIME,     "Slime",     0,               PAIN_SLIME},
    {WHIRLWIND, "Whirlwind", SCORE_WHIRLWIND, PAIN_WHIRLWIND},
    {LASTHEAD,  "Worm",      0,               PAIN_HEAD}
};

STRPTR objectdesc[LASTOBJECT + 1] =
{	"AFFIXER: Stops protectors rotating.",
	"AMMO: 2-6 bullets.",
	"ARMOUR: Immune to most damage.",
        "BIAS: Rules changes in your favour.",
	"BOMB: An explosion.",
	"BONUS: Random letter.",
	"CLOCK: Extra time.",
        "CONVERTER: Fragments to missiles.",
        "CUTTER: Cuts a tunnel through tail.",
        "CYCLONE: Unleashes a whirlwind.",
        "ENCLOSER: Rectangular enclosure.",
        "FREEDOM: Leave remnants behind.",
        "GROWER: Enlarges silver and gold.",
	"HEALER: 100/200 lives.",
        "ICE: Freezes enemies.",
	"LIFE: 2-6 lives.",
        "LIGHTNING: Flashes around tail.",
        "MAGNET: Attracts all objects.",
	"MISSILE: A guided missile.",
	"MULTIPLIER: More points.",
	"NITRO: Diagonal movement.",
        "POWER: Thicker bullets.",
	"PROTECTOR: An orbiting companion.",
	"PULSE: Fragment explosion.",
        "PUSHER: Lets you push things.",
	"REMNANTS: Bullets leave a trail.",
        "SIDESHOT: Shoot sideways.",
	"SLAYER: Smart bomb.",
	"SLOWER: Slows creatures down.",
	"SWITCHER: Changes tail colours.",
        "TREASURE: Treasure level.",
        "UMBRELLA: Skip 2-3 levels."
};

UWORD chip IsoImageData[ARRAYSIZE + 1][ISOSQUAREY * 4] =
{ {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* AFFIXER */
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00,
	0x3FE0,	0x2720,	0x7FC0,	0x6EC0,	0xE180,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3BE0,	0x3BE0,	0x7BC0,	0x7BC0,	0xFB80,	0xF180,		/* AMMO */
	0x0400,	0x0400,	0x0400,	0x0400,	0x0400,	0x0E00,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0400,	0x0000,	0x0400,	0x0000,	0x0400,	0x0000 },
  {	0x1FC0,	0x0F80,	0x0400,	0x3180,	0x6300,	0x0000,		/* ARMOUR */
	0x2020,	0x3060,	0x7BC0,	0x4E40,	0x9C80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x4E40,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3F80,	0x3F20,	0x7E40,	0x1CC0,	0xC980,	0xE380,		/* BIAS */
	0x0060,	0x00C0,	0x0180,	0x6300,	0x3600,	0x1C00,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0060,	0x00C0,	0x0180,	0x6300,	0x3600,	0x1C00 },
  {	0x3BE0,	0x37E0,	0x7FC0,	0x41C0,	0xC180,	0xFF80,		/* BOMB */
	0x0600,	0x0800,	0x3E00,	0x4100,	0x4100,	0x3E00,
	0x3FE0,	0x37E0,	0x41C0,	0x3EC0,	0xBE80,	0xC180,
	0x0600,	0x0800,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3F80,	0x3F20,	0x7E40,	0x1CC0,	0xC980,	0xE380,		/* BONUS */
	0x0060,	0x00C0,	0x0180,	0x6300,	0x3600,	0x1C00,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3C20,	0x3FE0,	0x46C0,	0x7CC0,	0xC080,	0xFF80,		/* CLOCK */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3C20,	0x03E0,	0x3F40,	0x7F40,	0xBF00,	0xC080,
	0x03C0,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  { 0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F, // CONVERTER
    0xC41F, 0xC41F, 0xFFFF, 0x843F, 0x047F, 0x007F,
    0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F,
    0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F },
  {     0x3BE0, 0x37E0, 0x60C0, 0x7DC0, 0xFB80, 0xFF80,         /* CUTTER */
        0x0400, 0x0800, 0x1F00, 0x0200, 0x0400, 0x0000,
        0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80,
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {	0x3FE0,	0x3060,	0x7FC0,	0x7BC0,	0xFF80,	0xFF80,         /* CYCLONE */
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
        0x0F80,	0x3FE0, 0x1F80,	0x0E00,	0x0400,	0x0400 },
  { 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // ENCLOSER
    0xC000, 0xCF80, 0x8FA0, 0xFFA0, 0x0C40, 0x0C40,
    0x0000, 0x0F80, 0x0F80, 0x7F80, 0x0C00, 0x0C00,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {     0x2060,	0x1FA0,	0x5880,	0x5780,	0xD800,	0xEF80,         // FREEDOM
	0x1F80,	0x2040,	0x2740,	0x2840,	0x2780,	0x1000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GROWER */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3020,	0x2DE0,	0x60C0,	0x7B40,	0x8080,	0xF780,
	0x0DC0,	0x1000,	0x1B00,	0x0080,	0x7700,	0x0000 },
  {	0x3FE0,	0x0840,	0x7FC0,	0x4E40,	0xFF80,	0x4200,		/* HEALER */
	0x0000,	0x28E0,	0x0000,	0x6EC0,	0x0000,	0xE280,
	0x3FE0,	0x3FC0,	0x7FC0,	0x7FC0,	0xFF80,	0x7F80,
	0x0000,	0x2880,	0x0000,	0x2E80,	0x0000,	0x2280 },
  {	0x3FE0,	0x3F60,	0x7E40,	0x7E40,	0xFE80,	0xFF80,		/* ICE */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x41C0,	0x41C0,	0xC180,	0xFF80,
	0x0000,	0x1F80,	0x0180,	0x0180,	0x0100,	0x0000 },
  {	0x3FE0,	0x2EE0,	0x5540,	0x6AC0,	0xF580,	0xFB80,		/* LIFE */
	0x0000,	0x1100,	0x3B80,	0x1F00,	0x0E00,	0x0400,
	0x3FE0,	0x2EE0,	0x4440,	0x60C0,	0xF180,	0xFB80,
	0x0000,	0x1100,	0x3B80,	0x1F00,	0x0E00,	0x0400 },
  {	0x3FFF,	0x2FFF,	0x7FDF,	0x7FDF,	0xFF9F,	0xFF9F,		/* LIGHTNING */
	0x0400,	0x0800, 0x1F00,	0x0200,	0x0400,	0x0000,
	0x3FE0,	0x2FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0400,	0x0800, 0x1F00,	0x0200,	0x0400,	0x0000 },
  {	0x3FE0, 0x20E0,	0x4E40,	0x4E40,	0xFF80,	0xFF80,         // MAGNET
        0x0000,	0x1F00, 0x3180,	0x3180,	0x0000,	0x0000,
	0x3FE0,	0x20E0,	0x4E40,	0x4E40,	0xCE00,	0xFF80,
        0x0000,	0x1F00, 0x3180,	0x3180,	0x0000,	0x0000 },
  { 0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F, // MISSILE
    0xC41F, 0xC41F, 0xFFFF, 0x843F, 0x047F, 0x007F,
    0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F,
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F },
  {	0x30E0,	0x3F60,	0x7EC0, 0x7DC0,	0xF380,	0xF000,		/* MULTIPLIER */
	0x0F00,	0x2880,	0x1100,	0x2A00,	0x0C00,	0x0F80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* NITRO */
	0x0000,	0x0000,	0x0A00,	0x0A00,	0x0A00,	0x0A00,
	0x3BE0,	0x31E0,	0x60C0,	0x71C0,	0xF180,	0xF180,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x39E0,	0x30E0,	0x4000,	0x6040,	0xF080,	0xF980,		/* POWER */
	0x0600,	0x0F00,	0x3FC0,	0x1F80,	0x0F00,	0x0600,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0200,	0x0300,	0x03C0,	0x1C00,	0x0C00,	0x0400 },
  {	0x2020,	0x18C0,	0x0000,	0x1100,	0x9E80,	0xC180,		/* PROTECTOR */
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00,
	0x3FE0,	0x2720,	0x7FC0,	0x6EC0,	0xE180,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* PULSE */
	0x2440,	0x0000, 0x4000,	0x0040,	0x0000,	0x4480,
	0x3FE0,	0x3FE0,	0x71C0,	0x71C0,	0xFF80,	0xFF80,
	0x2440,	0x0000, 0x4E00, 0x0E40,	0x0000,	0x4480 },
  {     0x3FE0, 0x3FE0,	0x7FC0, 0x7FC0, 0xFF80, 0xFF80,         // PUSHER
	0x0000,	0x1800,	0x7800,	0x0380,	0x0300,	0x0000,
	0x3BE0,	0x20E0,	0x0000, 0x4040, 0xE080,	0xFB80,
	0x0400,	0x1F00,	0x7FC0,	0x3F80,	0x1F00,	0x0400 },
  {	0x3FE0,	0x3FE0,	0x73C0,	0x71C0,	0xF980,	0xFF80,		/* REMNANT */
	0x0000,	0x0000,	0x0C00,	0x0E00,	0x0600,	0x0000,
	0x3FE0,	0x3FE0, 0x7FC0,	0x7DC0,	0xF980,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FFF,	0x3FFF,	0x7FDF,	0x7FDF,	0xFF9F,	0xFF9F,         /* SIDESHOT */
	0x0400,	0x0C00,	0x3C00,	0x0380,	0x0300,	0x0200,
	0x3BE0,	0x33E0,	0x43C0,	0x7C40,	0xFC80,	0xFD80,
	0x0600,	0x0F00,	0x3FC0,	0x1F80,	0x0F00,	0x0600 },
  {	0x3FE0,	0x3FE0,	0x71C0,	0x71C0,	0xFF80,	0xFF80,		/* SLAYER */
	0x2440,	0x0000,	0x4E00,	0x0E40,	0x0000,	0x4480,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x01E0,	0x3060,	0x76C0,	0x6DC0,	0xC180,	0xF000,		/* SLOWER */
	0x3E00,	0x0F80, 0x0900,	0x1200,	0x3E00,	0x0F80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0F80, 0x0100,	0x0200,	0x0400,	0x0F80 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,		/* SWITCHER */
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000, 0x0000,	0x0000 },
  {	0x3220,	0x2FE0,	0x64C0,	0x7F40,	0x8880,	0xFF80,		/* TREASURE */
	0x0DC0,	0x1000,	0x1B00,	0x0080,	0x7700,	0x0000,
	0x3DE0,	0x3DE0,	0x7BC0,	0x7BC0,	0xF780,	0xF780,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x21E0,	0x00E0,	0x0040,	0x77C0,	0xF780,	0xF980,		/* UMBRELLA */
	0x1E00,	0x3F00,	0x7F80,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x2020,	0x4040,	0x4040,	0x8080,	0xFF80,		/* EMPTY */
	0x3FC0,	0x3FC0,	0x7F80,	0x7F80,	0xFF00,	0x8000,
	0x0020,	0x0020,	0x0040,	0x0040, 0x0080,	0x7F80,
	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x2020,	0x4040,	0x4040,	0x8080,	0xFF80,		/* SILVER */
	0x0020,	0x0020,	0x0040,	0x0040,	0x0080,	0x7F80,
	0x0000,	0x1FC0,	0x3F80,	0x3F80,	0x7F00,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x2020,	0x4040,	0x4040,	0x8080,	0xFF80,		/* GOLD */
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x3FC0,	0x3FC0,	0x7F80,	0x7F80,	0xFF00,	0x8000 },
  {	0x0000,	0x0440,	0x5DC0,	0x7740,	0x5500,	0xFF80,		/* TELEPORT */
	0x3FE0,	0x3FE0,	0x7FC0,	0x7740,	0x4400,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0880,	0xAA80,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0, 0x7DC0,	0xF980,	0xFF80,		/* FRAGMENT */
	0x0000,	0x0000,	0x0000,	0x0200,	0x0600,	0x0000,
	0x3FE0,	0x3FE0,	0x73C0,	0x71C0,	0xF980,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0000,	0x0E00,	0x1F00,	0x1F80,	0x0F80,	0x0700,		/* ORB */
	0x3FE0,	0x3FE0,	0x7FC0,	0x7F40,	0xFE00,	0xF880,
	0x0000,	0x0E00,	0x1F00,	0x1F80,	0x0F80,	0x0700,
	0x0000,	0x0E00,	0x1F00,	0x1F00,	0x0E00,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* Green Protector */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x2020,	0x18C0,	0x0000,	0x1100,	0x9E80,	0xC180,
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* Red Protector */
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00,
	0x2020,	0x18C0,	0x0000,	0x1100,	0x9E80,	0xC180,
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* Blue Protector */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* Yellow Protector */
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x1FC0,	0x2720,	0x7FC0,	0x6EC0,	0x6100,	0x3E00 },
  {	0x1F80,	0x2FC0,	0x3000,	0x3000,	0x1F80,	0x0F80,		/* Green C */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0FC0,	0x1000,	0x1000,	0x0000,	0x0F80,
	0x2060,	0x1020,	0x4FC0,	0x4FC0,	0xE000,	0xF000 },
  {	0x1F00,	0x2F80,	0x30C0,	0x30C0,	0x1F00,	0x0F80,		/* Red O */
	0x20E0,	0x1060,	0x4F00,	0x4F00,	0xE080,	0xF000,
	0x0000,	0x0F00,	0x1040,	0x1040,	0x0000,	0x0F80,
	0x20E0,	0x1060,	0x4F00,	0x4F00,	0xE080,	0xF000 },
  {	0x1B00,	0x2D80,	0x36C0,	0x32C0,	0x3080,	0x1000,		/* Blue M */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x24E0,	0x1B60,	0x5B40,	0x5F40,	0xDF00,	0xFF80,
	0x24E0,	0x1260,	0x4900,	0x4D00,	0xCF00,	0xEF80 },
  {	0x3F00,	0x3F80,	0x3F40,	0x3F80,	0x3000,	0x1000,		/* Yellow P */
	0x00E0,	0x0060,	0x4080,	0x4040,	0xCF80,	0xEF80,
	0x00E0,	0x1F60,	0x40C0,	0x5FC0,	0xDF80,	0xFF80,
	0x00E0,	0x0060,	0x4080,	0x4040,	0xCF80,	0xEF80 },
  {	0x2000,	0x3000,	0x3000,	0x3000,	0x3F80,	0x1F80,		/* Green L */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x1000,	0x1000,	0x1000,	0x0000,	0x1F80,
	0x1FE0,	0x0FE0,	0x4FC0,	0x4FC0,	0xC000,	0xE000 },
  {	0x3F80,	0x3FC0,	0x3C00,	0x3E00,	0x3F80,	0x1F80,		/* Red E */
	0x0060,	0x0020,	0x43C0,	0x41C0,	0xC000,	0xE000,
	0x0000,	0x1FC0,	0x0000,	0x1E00,	0x0000,	0x1F80,
	0x0060,	0x0020,	0x43C0,	0x41C0,	0xC000,	0xE000 },
  {	0x3F80,	0x1FC0,	0x0600,	0x0600,	0x0600,	0x0200,		/* Blue T */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0060,	0x3BC0,	0x7BC0,	0x7BC0,	0xFB80,	0xFF80,
	0x0060,	0x2000,	0x79C0,	0x79C0,	0xF980,	0xFD80 },
  {	0x3F80,	0x3FC0,	0x3C00,	0x3E00,	0x3F00,	0x1F80,		/* Yellow E */
	0x0060,	0x0000,	0x43C0,	0x41C0,	0xC080,	0xE000,
	0x0060,	0x1FC0,	0x43C0,	0x5FC0,	0xC080,	0xFF80,
	0x0060,	0x0000,	0x43C0,	0x41C0,	0xC080,	0xE000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* SKULL */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3060,	0x2DA0,	0x4040,	0x4E40,	0xDD80,	0xE380,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x2520,	0x0000,	0x4040,	0x4040,	0x0000,	0x9480,		/* SLIME */
	0x1240,	0x2AA0,	0x2A80,	0x1500,	0xD500,	0x2A00,
	0x3760,	0x2AA0,	0x6AC0,	0x5540,	0xD500,	0xBE80,
	0x0880,	0x1540,	0x1500,	0x2A80,	0x2A80,	0x4100 },
  {	0x3FC0,	0x3FC0,	0x7F80,	0x7F80,	0xFF00,	0x8000,		/* STONE */
	0x3FE0,	0x2020,	0x4040,	0x4040,	0x8080,	0xFF80,
	0x0000,	0x1FC0,	0x3F80,	0x3F80,	0x7F00,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {     0x23E0, 0x23E0, 0x63C0, 0x00C0, 0x6300, 0x8080, /* GOAT */
	0x1C00,	0x1C00,	0x1C00,	0x7F00,	0x9C80,	0x7F00,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x1C00,	0x1C00,	0x1C00,	0x7F00,	0x9C80,	0x7F00 },
  {	0x0000,	0x1FC0,	0x3F80,	0x3F80,	0x7F00,	0x0000, /* WOOD */
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x3FC0,	0x3FC0,	0x7F80,	0x7F80,	0xFF00,	0x8000,
	0x3FC0,	0x2000,	0x4000,	0x4000,	0x8000,	0x8000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80, /* Green Tail */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80, /* Red Tail */
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80, /* Blue Tail */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0, 0x7FC0,	0xFF80,	0xFF80, /* Yellow Tail */
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80 },
  {     0x2000, 0x1780, 0x1FC0, 0x1780, 0x2000, 0x0000, // FISH
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0000, 0x0000, 0x0300, 0x0000, 0x0000, 0x0000,
        0x001F, 0x001F, 0x031F, 0x001F, 0x001F, 0x001F },
  { 0x0000, 0x1800, 0x0000, 0x0000, 0x0000, 0x0000, // OTTER
    0x5800, 0x6400, 0x9F20, 0xAAA0, 0x2AC0, 0x0040,
    0x1800, 0x2400, 0x1F00, 0x2A80, 0x2A80, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7DC0, 0xF980, 0xFF80, /* Green Fire */
	0x0000,	0x0000,	0x0000,	0x0200,	0x0600,	0x0000,
	0x3FE0,	0x3FE0,	0x73C0,	0x71C0,	0xF980,	0xFF80,
	0x0000,	0x0000,	0x0C00,	0x0C00,	0x0000,	0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7DC0, 0xF980, 0xFF80, /* Red Fire */
	0x0000,	0x0000,	0x0C00,	0x0E00,	0x0600,	0x0000,
	0x3FE0,	0x3FE0,	0x73C0,	0x71C0,	0xF980,	0xFF80,
	0x0000,	0x0000,	0x0C00,	0x0C00,	0x0000,	0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7DC0, 0xF980, 0xFF80, /* Blue Fire */
	0x0000,	0x0000,	0x0000,	0x0200,	0x0600,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7DC0,	0xF980,	0xFF80,
	0x0000,	0x0000,	0x0C00,	0x0C00,	0x0000,	0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7DC0, 0xF980, 0xFF80, /* Yellow Fire */
	0x0000,	0x0000,	0x0C00,	0x0E00,	0x0600,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7DC0,	0xF980,	0xFF80,
	0x0000,	0x0000,	0x0C00,	0x0C00,	0x0000,	0x0000 },
  { 0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F, // Green Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 0
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0400, 0x0400, 0x7FC0, 0x0400, 0x0400, 0x0000 },
  { 0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F, // Red Missile
    0xC41F, 0xC41F, 0xFFFF, 0x843F, 0x047F, 0x007F, // Frame 0
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0400, 0x0400, 0x7FC0, 0x0400, 0x0400, 0x0000 },
  { 0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F, // Blue Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 0
    0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F,
    0x0400, 0x0400, 0x7FC0, 0x0400, 0x0400, 0x0000 },
  { 0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F, // Yellow Missile
    0xC41F, 0xC41F, 0xFFFF, 0x843F, 0x047F, 0x007F, // Frame 0
    0x041F, 0x041F, 0x7FDF, 0x041F, 0x041F, 0x001F,
    0x0400, 0x0400, 0x7FC0, 0x0400, 0x0400, 0x0000 },
  {	0x38E0,	0x38E0,	0x0E00,	0x0E00,	0xE380,	0xE380,		/* START */
	0x0000,	0x0000,	0x01C0,	0x01C0,	0x1C00,	0x1C00,
	0x3FE0,	0x3FE0,	0x0E00,	0x0E00,	0xFF80,	0xFF80,
	0x0700,	0x0700,	0x71C0,	0x71C0,	0x1C00,	0x1C00 },
  {     0x2060, 0x2F60, 0x6040, 0x6F40, 0x8C00, 0x8C00,         /* MUSIC */
	0x1F80,	0x1080,	0x1F80,	0x1080,	0x7380,	0x7380,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80,         /* FX */
	0x0220,	0x0140,	0x0180,	0x0300,	0x0500,	0x0880,
	0x3DC0,	0x3EA0,	0x7E40,	0x7CC0,	0xFA80,	0xF700,
	0x1A20,	0x2140,	0x4180,	0x7300,	0x8500,	0x8880 },
  {	0x3FE0,	0x38E0,	0x7780,	0x7780,	0xFF80,	0xF800,		/* ZERO */
	0x0000,	0x0700,	0x0840,	0x0840,	0x0000,	0x0780,
	0x30E0,	0x2860,	0x6700,	0x6700,	0xF080,	0xF800,
	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3EE0,	0x7EC0,	0x7EC0,	0xFF80,	0xFC00,		/* ONE */
	0x0000,	0x0100,	0x0100,	0x0100,	0x0000,	0x0380,
	0x3DE0,	0x38E0,	0x7CC0,	0x7CC0,	0xF880,	0xFC00,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x30E0,	0x7F80,	0x7840,	0xFF80,	0xF000,		/* TWO */
	0x0000,	0x0F00,	0x0040,	0x0780,	0x0000,	0x0F80,
	0x20E0,	0x3060,	0x7080,	0x6840,	0xE080,	0xF000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x30E0,	0x7F80,	0x7CC0,	0xFF80,	0xF000,		/* Three */
	0x0000,	0x0F00,	0x0040,	0x0300,	0x0000,	0x0F80,
	0x20E0,	0x3060,	0x7880,	0x7C40,	0xE080,	0xF000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3760,	0x7FC0,	0x7100,	0xFF00,	0xFF00,		/* Four */
	0x0000,	0x0880,	0x0000,	0x0EC0,	0x0080,	0x0080,
	0x2EE0,	0x2660,	0x6040,	0x7000,	0xFE00,	0xFF00,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3020,	0x7FC0,	0x70C0,	0xFF80,	0xF000,		/* Five */
	0x0000,	0x0FC0,	0x0000,	0x0F00,	0x0000,	0x0F80,
	0x2060,	0x2020,	0x60C0,	0x7040,	0xE080,	0xF000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3820,	0x7FC0,	0x70C0,	0xFF80,	0xF800,		/* Six */
	0x0000,	0x07C0,	0x0000,	0x0F00,	0x0000,	0x0780,
	0x3060,	0x2820,	0x60C0,	0x6040,	0xF080,	0xF800,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x30A0,	0x7F80,	0x7F40,	0xFF00,	0xFE80,		/* Seven */
	0x0000,	0x0F40,	0x0040,	0x0080,	0x0080,	0x0100,
	0x2060,	0x3020,	0x7E80,	0x7E40,	0xFD00,	0xFE80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x38E0,	0x7F80,	0x78C0,	0xFF00,	0xF800,		/* Eight */
	0x0000,	0x0700,	0x0040,	0x0700,	0x0080,	0x0780,
	0x30E0,	0x2860,	0x7080,	0x6840,	0xF000,	0xF800,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x38A0,	0x7F80,	0x7880,	0xFF80,	0xFF80,		/* Nine */
	0x0000,	0x0740,	0x0040,	0x0740,	0x0000,	0x0000,
	0x3060,	0x2820,	0x7000,	0x7800,	0xFF00,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENHEADUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x38E0,	0x3060,	0x4040,	0x0000,	0x6300,	0x0000,
	0x0700,	0x0F80,	0x3F80,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0, 0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDHEADUP */
	0x0700,	0x0F80,	0x3F80,	0x4E40,	0x9C80,	0xFF80,
	0x38E0,	0x3060,	0x4040,	0x0000,	0x6300,	0x0000,
	0x0700,	0x0F80,	0x3F80,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEHEADUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x4E40,	0xFF80,	0xFF80,
	0x0700,	0x0F80,	0x3F80,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWHEADUP */
	0x0700,	0x0F80,	0x3F80,	0x4E40,	0x9C80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x4E40,	0xFF80,	0xFF80,
	0x0700,	0x0F80,	0x3F80,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENHEADDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x18C0,	0x0040,	0x4040,	0xC180,	0xE380,
	0x3FE0,	0x2720,	0x4E00,	0x3F80,	0x3E00,	0x1C00 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDHEADDOWN */
	0x3FE0,	0x2720,	0x4E40,	0x3F80,	0x3E00,	0x1C00,
	0x0000,	0x18C0,	0x0000,	0x4040,	0xC180,	0xE380,
	0x3FE0,	0x2720,	0x4E40,	0x3F80,	0x3E00,	0x1C00 },
  {	0x3FE0, 0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEHEADDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x4E40,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x2720,	0x4E40,	0x3F80,	0x3E00,	0x1C00 },
  {	0x3FE0, 0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWHEADDOWN */
	0x3FE0,	0x2720,	0x4E40,	0x3F80,	0x3E00,	0x1C00,
	0x3FE0,	0x3FE0,	0x4E40,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x2720,	0x4E40,	0x3F80,	0x3E00,	0x1C00 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENHEADLEFT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3C00,	0x30C0,	0x0000,	0x0000,	0xC300,	0xF000,
	0x03E0,	0x0C20,	0x7FC0,	0x7FC0,	0x3080,	0x0F80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDHEADLEFT */
	0x03E0,	0x0C20,	0x7FC0,	0x7FC0,	0x3080,	0x0F80,
	0x3C00,	0x30C0,	0x0000,	0x0000,	0xC300,	0xF000,
	0x03E0,	0x0C20,	0x7FC0,	0x7FC0,	0x3080,	0x0F80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEHEADLEFT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3CE0,	0x7FC0,	0x7FC0,	0xF380,	0xFF80,
	0x03E0,	0x0C20,	0x7FC0,	0x7FC0,	0x3080,	0x0F80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWHEADLEFT */
	0x03E0,	0x0C20,	0x7FC0,	0x7FC0,	0x3080,	0x0F80,
	0x3FE0,	0x3CE0,	0x7FC0,	0x7FC0,	0xF380,	0xFF80,
	0x03E0,	0x0C20,	0x7FC0,	0x7FC0,	0x3080,	0x0F80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENHEADRIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x01E0,	0x1860,	0x0000,	0x0000,	0x6180,	0x0780,
	0x3E00,	0x2180,	0x7FC0,	0x7FC0,	0x8600,	0xF800 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDHEADRIGHT */
	0x3E00,	0x2180,	0x7FC0,	0x7FC0,	0x8600,	0xF800,
	0x01E0,	0x1860,	0x0000,	0x0000,	0x6180,	0x0780,
	0x3E00,	0x2180,	0x7FC0,	0x7FC0,	0x8600,	0xF800 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEHEADRIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x39E0,	0x7FC0,	0x7FC0,	0xE780,	0xFF80,
	0x3E00,	0x2180,	0x7FC0,	0x7FC0,	0x8600,	0xF800 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWHEADRIGHT */
	0x3E00,	0x2180,	0x7FC0,	0x7FC0,	0x8600,	0xF800,
	0x3FE0,	0x39E0,	0x7FC0,	0x7FC0,	0xE780,	0xFF80,
	0x3E00,	0x2180,	0x7FC0,	0x7FC0,	0x8600,	0xF800 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENMODEUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x1FC0,	0x0F80,	0x0400,	0x0000,	0x6300,	0x0000,
	0x2020,	0x3060,	0x7BC0,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDMODEUP */
	0x2020,	0x3060,	0x7BC0,	0x4E40,	0x9C80,	0xFF80,
	0x1FC0,	0x0F80,	0x0400,	0x0000,	0x6300,	0x0000,
	0x2020,	0x3060,	0x7BC0,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEMODEUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x4E40,	0xFF80,	0xFF80,
	0x2020,	0x3060,	0x7BC0,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWMODEUP */
	0x2020,	0x3060,	0x7BC0,	0x4E40,	0x9C80,	0xFF80,
	0x3FE0,	0x3FE0,	0x7FC0,	0x4E40,	0xFF80,	0xFF80,
	0x2020,	0x3060,	0x7BC0,	0x4E40,	0x9C80,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENMODEDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x18C0,	0x0000,	0x0400,	0x3E00,	0x7F00,
	0x3FE0,	0x2720,	0x4E40,	0x7BC0,	0xC180,	0x8080 },
  {	0x3FE0, 0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDMODEDOWN */
	0x3FE0,	0x2720,	0x4E40,	0x7BC0,	0xC180,	0x8080,
	0x0000,	0x18C0,	0x0000,	0x0400,	0x3E00,	0x7F00,
	0x3FE0,	0x2720,	0x4E40,	0x7BC0,	0xC180,	0x8080 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEMODEDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x4E40,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x2720,	0x4E40,	0x7BC0,	0xC180,	0x8080 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWMODEDOWN */
	0x3FE0,	0x2720,	0x4E40,	0x7BC0,	0xC180,	0x8080,
	0x3FE0,	0x3FE0,	0x4E40,	0x7FC0,	0xFF80,	0xFF80,
	0x3FE0,	0x2720,	0x4E40,	0x7BC0,	0xC180,	0x8080 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENMODELEFT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x20C0,	0x7000,	0x7000,	0x8300,	0x0000,
	0x3FE0,	0x1C20,	0x0FC0,	0x0FC0,	0x7080,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDMODELEFT */
	0x3FE0,	0x1C20,	0x0FC0,	0x0FC0,	0x7080,	0xFF80,
	0x0000,	0x20C0,	0x7000,	0x7000,	0x8300,	0x0000,
	0x3FE0,	0x1C20,	0x0FC0,	0x0FC0,	0x7080,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEMODELEFT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3CE0,	0x7FC0,	0x7FC0,	0xF380,	0xFF80,
	0x3FE0,	0x1C20,	0x0FC0,	0x0FC0,	0x7080,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWMODELEFT */
	0x3FE0, 0x1C20,	0x0FC0,	0x0FC0,	0x7080,	0xFF80,
	0x3FE0,	0x3CE0,	0x7FC0,	0x7FC0,	0xF380,	0xFF80,
	0x3FE0,	0x1C20,	0x0FC0,	0x0FC0,	0x7080,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* GREENMODERIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x1820,	0x01C0,	0x01C0,	0x6080,	0x0000,
	0x3FE0,	0x21C0,	0x7E00,	0x7E00,	0x8700,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* REDMODERIGHT */
	0x3FE0,	0x21C0,	0x7E00,	0x7E00,	0x8700,	0xFF80,
	0x0000,	0x1820,	0x01C0,	0x01C0,	0x6080,	0x0000,
	0x3FE0,	0x21C0,	0x7E00,	0x7E00,	0x8700,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLUEMODERIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x39E0,	0x7FC0,	0x7FC0,	0xE780,	0xFF80,
	0x3FE0,	0x21C0,	0x7E00,	0x7E00,	0x8700,	0xFF80 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* YELLOWMODERIGHT */
	0x3FE0,	0x21C0,	0x7E00,	0x7E00,	0x8700,	0xFF80,
	0x3FE0,	0x39E0,	0x7FC0,	0x7FC0,	0xE780,	0xFF80,
	0x3FE0,	0x21C0,	0x7E00,	0x7E00,	0x8700,	0xFF80 },
  {	0x0000,	0x1FC0,	0x3F80,	0x3F80,	0x7F00,	0x0000,		/* METAL */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0020,	0x1FE0,	0x3FC0,	0x3FC0,	0x7F80,	0x7F80 },
  {	0x3BE0,	0x3BE0,	0x71C0,	0x60C0,	0xE080,	0xF180,		/* Green Drip */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3BE0,	0x3BE0,	0x71C0,	0x60C0,	0xE080,	0xF180,
	0x0400,	0x0400,	0x0E00,	0x1F00,	0x1F00,	0x0E00 },
  {	0x3BE0,	0x3BE0,	0x71C0,	0x60C0,	0xE080,	0xF180,		/* Red Drip */
	0x0400,	0x0400,	0x0E00,	0x1F00,	0x1F00,	0x0E00,
	0x3BE0,	0x3BE0,	0x71C0,	0x60C0,	0xE080,	0xF180,
	0x0400,	0x0400,	0x0E00,	0x1F00,	0x1F00,	0x0E00 },
  {	0x3BE0,	0x3BE0,	0x71C0,	0x60C0,	0xE080,	0xF180,		/* Blue Drip */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0400,	0x0400,	0x0E00,	0x1F00,	0x1F00,	0x0E00 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* Yellow Drip */
	0x0400,	0x0400,	0x0E00,	0x1F00,	0x1F00,	0x0E00,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0400,	0x0400,	0x0E00,	0x1F00,	0x1F00,	0x0E00 },
  {	0x3FE0, 0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* BLACKENED */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,		/* WHITENED */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FC0,	0x3CC0, 0x07C0,	0x7FC0,	0xE600,	0xCE00,		/* PENGUIN */
	0x0000,	0x3800,	0x7800,	0x0000,	0x1980,	0x3180,
	0x3C00,	0x3C00,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0400,	0x3C00,	0x7F80,	0x0F80,	0x0000,	0x0000 },
  {	0x3FE0,	0x3060,	0x7FC0,	0x7BC0,	0xFF80,	0xFF80,         /* WHIRLWIND */
        0x0F80,	0x3FE0, 0x1F80,	0x0E00,	0x0400,	0x0400,
	0x3060,	0x0000,	0x6040,	0x71C0,	0xFB80,	0xFB80,
        0x0F80,	0x3FE0, 0x1F80,	0x0E00,	0x0400,	0x0400 },
  {	0x3FE0, 0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,         /* DOG (chasing) */
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x3AE0,	0x3C20,	0x31C0,	0x41C0,	0xAA80,	0xFF80,
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3AE0, 0x3C20,	0x31C0,	0x41C0,	0xAA80,	0xFF80,         /* DOGAWAKENING */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
        0x3FE0,	0x3FE0, 0x7FC0,	0x7FC0,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0,	0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,         /* DOGDORMANT */
        0x0500,	0x03C0, 0x4E00,	0x3E00,	0x5500,	0x0000,
	0x3AE0,	0x3C20,	0x31C0,	0x41C0,	0xAA80,	0xFF80,
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3FE0, 0x3FE0,	0x7FC0,	0x7FC0,	0xFF80,	0xFF80,         /* CLOUD */
	0x001F,	0x001F,	0x001F,	0x001F,	0x001F,	0x001F,
	0x3FE0,	0x2EE0,	0x71C0,	0x6EC0,	0xFF80,	0xFF80,
	0x001F,	0x0E1F,	0x71DF,	0x0E1F,	0x001F,	0x001F },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80, /* ALL */
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x3BE0, 0x0A60, 0x71C0, 0x71C0, 0xCA00, 0xFB80,
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80, /* Green Arrow */
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x39E0, 0x27E0, 0x0000, 0x67C0, 0xF980, 0xFF80,
        0x0600, 0x1800, 0x7FC0, 0x1800, 0x0600, 0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80, /* Red Arrow */
        0x0600, 0x1800, 0x7FC0, 0x1800, 0x0600, 0x0000,
        0x39E0, 0x27E0, 0x0000, 0x67C0, 0xF980, 0xFF80,
        0x0600, 0x1800, 0x7FC0, 0x1800, 0x0600, 0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80, /* Blue Arrow */
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80,
        0x0600, 0x1800, 0x7FC0, 0x1800, 0x0600, 0x0000 },
  {     0x7FC0, 0x7FC0, 0xFF80, 0xFF80, 0xFF00, 0xFF00, /* Yellow Arrow */
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000,
        0x7FC0, 0x7FC0, 0xFF80, 0xFF80, 0xFF00, 0xFF00,
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000 },
  {     0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80, // DYNAMITE
        0x0000, 0x0000, 0x1F00, 0x1F00, 0x0000, 0x0000,
        0x0000, 0x1FC0, 0x3F80, 0x3F80, 0x7F00, 0x0000,
        0x3FE0, 0x3FE0, 0x7FC0, 0x7FC0, 0xFF80, 0xFF80 },
  {     0x3760, 0x1F80, 0x7FC0, 0x3F00, 0xDD80, 0x1C00, // OCTOPUS
	0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
	0x0000, 0x0000, 0x1B00, 0x0000, 0x0000, 0x0000,
	0x001F, 0x001F, 0x1B1F, 0x001F, 0x001F, 0x001F },
  { 0x021F, 0x041F, 0x3F9F, 0x045F, 0x081F, 0x001F, // Green Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 1
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0200, 0x0400, 0x3F80, 0x0440, 0x0800, 0x0000 },
  { 0x011F, 0x321F, 0x0E1F, 0x099F, 0x101F, 0x001F, // Green Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 2
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0100, 0x3200, 0x0E00, 0x0980, 0x1000, 0x0000 },
  { 0x209F, 0x1B1F, 0x041F, 0x1B1F, 0x209F, 0x001F, // Green Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 3
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x2080, 0x1B00, 0x0400, 0x1B00, 0x2080, 0x0000 },
  { 0x105F, 0x099F, 0x0E1F, 0x321F, 0x411F, 0x001F, // Green Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 4
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x1040, 0x0980, 0x0E00, 0x3200, 0x4100, 0x0000 },
  { 0x081F, 0x045F, 0x3F9F, 0x441F, 0x021F, 0x001F, // Green Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 5
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0800, 0x0440, 0x3F80, 0x4400, 0x0200, 0x0000 },
  { 0x021F, 0x041F, 0x3F9F, 0x045F, 0x081F, 0x001F, // Red Missile
    0xC21F, 0xC41F, 0xBFBF, 0x847F, 0x087F, 0x007F, // Frame 1
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0200, 0x0400, 0x3F80, 0x0440, 0x0800, 0x0000 },
  { 0x011F, 0x321F, 0x0E1F, 0x099F, 0x101F, 0x001F, // Red Missile
    0xC11F, 0xF21F, 0x8E3F, 0x89BF, 0x107F, 0x007F, // Frame 2
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0100, 0x3200, 0x0E00, 0x0980, 0x1000, 0x0000 },
  { 0x209F, 0x1B1F, 0x041F, 0x1B1F, 0x209F, 0x001F, // Red Missile
    0xE09F, 0xDB1F, 0x843F, 0x9B3F, 0x20FF, 0x007F, // Frame 3
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x2080, 0x1B00, 0x0400, 0x1B00, 0x2080, 0x0000 },
  { 0x105F, 0x099F, 0x0E1F, 0x321F, 0x411F, 0x001F, // Red Missile
    0xD05F, 0xC99F, 0x8E3F, 0xB23F, 0x417F, 0x007F, // Frame 4
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x1040, 0x0980, 0x0E00, 0x3200, 0x4100, 0x0000 },
  { 0x081F, 0x045F, 0x3F9F, 0x441F, 0x021F, 0x001F, // Red Missile
    0xC81F, 0xC45F, 0xBFBF, 0xC43F, 0x027F, 0x007F, // Frame 5
    0x001F, 0x001F, 0x001F, 0x001F, 0x001F, 0x001F,
    0x0800, 0x0440, 0x3F80, 0x4400, 0x0200, 0x0000 },
  { 0x021F, 0x041F, 0x3F9F, 0x045F, 0x081F, 0x001F, // Blue Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 1
    0x021F, 0x041F, 0x3F9F, 0x045F, 0x081F, 0x001F,
    0x0200, 0x0400, 0x3F80, 0x0440, 0x0800, 0x0000 },
  { 0x011F, 0x321F, 0x0E1F, 0x099F, 0x101F, 0x001F, // Blue Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 2
    0x011F, 0x321F, 0x0E1F, 0x099F, 0x101F, 0x001F,
    0x0100, 0x3200, 0x0E00, 0x0980, 0x1000, 0x0000 },
  { 0x209F, 0x1B1F, 0x041F, 0x1B1F, 0x209F, 0x001F, // Blue Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 3
    0x209F, 0x1B1F, 0x041F, 0x1B1F, 0x209F, 0x001F,
    0x2080, 0x1B00, 0x0400, 0x1B00, 0x2080, 0x0000 },
  { 0x105F, 0x099F, 0x0E1F, 0x321F, 0x411F, 0x001F, // Blue Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 4
    0x105F, 0x099F, 0x0E1F, 0x321F, 0x411F, 0x001F,
    0x1040, 0x0980, 0x0E00, 0x3200, 0x4100, 0x0000 },
  { 0x081F, 0x045F, 0x3F9F, 0x441F, 0x021F, 0x001F, // Blue Missile
    0xC01F, 0xC01F, 0x803F, 0x803F, 0x007F, 0x007F, // Frame 5
    0x081F, 0x045F, 0x3F9F, 0x441F, 0x021F, 0x001F,
    0x0800, 0x0440, 0x3F80, 0x4400, 0x0200, 0x0000 },
  { 0x021F, 0x041F, 0x3F9F, 0x045F, 0x081F, 0x001F, // Yellow Missile
    0xC21F, 0xC41F, 0xBFBF, 0x847F, 0x087F, 0x007F, // Frame 1
    0x021F, 0x041F, 0x3F9F, 0x045F, 0x081F, 0x001F,
    0x0200, 0x0400, 0x3F80, 0x0440, 0x0800, 0x0000 },
  { 0x011F, 0x321F, 0x0E1F, 0x099F, 0x101F, 0x001F, // Yellow Missile
    0xC11F, 0xF21F, 0x8E3F, 0x89BF, 0x107F, 0x007F, // Frame 2
    0x011F, 0x321F, 0x0E1F, 0x099F, 0x101F, 0x001F,
    0x0100, 0x3200, 0x0E00, 0x0980, 0x1000, 0x0000 },
  { 0x209F, 0x1B1F, 0x041F, 0x1B1F, 0x209F, 0x001F, // Yellow Missile
    0xE09F, 0xDB1F, 0x843F, 0x9B3F, 0x20FF, 0x007F, // Frame 3
    0x209F, 0x1B1F, 0x041F, 0x1B1F, 0x209F, 0x001F,
    0x2080, 0x1B00, 0x0400, 0x1B00, 0x2080, 0x0000 },
  { 0x105F, 0x099F, 0x0E1F, 0x321F, 0x411F, 0x001F, // Yellow Missile
    0xD05F, 0xC99F, 0x8E3F, 0xB23F, 0x417F, 0x007F, // Frame 4
    0x105F, 0x099F, 0x0E1F, 0x321F, 0x411F, 0x001F,
    0x1040, 0x0980, 0x0E00, 0x3200, 0x4100, 0x0000 },
  { 0x081F, 0x045F, 0x3F9F, 0x441F, 0x021F, 0x001F, // Yellow Missile
    0xC81F, 0xC45F, 0xBFBF, 0xC43F, 0x027F, 0x007F, // Frame 5
    0x081F, 0x045F, 0x3F9F, 0x441F, 0x021F, 0x001F,
    0x0800, 0x0440, 0x3F80, 0x4400, 0x0200, 0x0000 },
  { 0x001F, 0x041F, 0x1F1F, 0x64DF, 0x001F, 0x001F, // BIRD
    0xC01F, 0xC41F, 0x843F, 0x843F, 0x007F, 0x007F, // Frame 0
    0x001F, 0x041F, 0x041F, 0x041F, 0x001F, 0x001F,
    0x0000, 0x0400, 0x0400, 0x0400, 0x0000, 0x0000 },
  { 0x001F, 0x041F, 0x7FDF, 0x041F, 0x001F, 0x001F, // Bird
    0xC01F, 0xC41F, 0x843F, 0x843F, 0x007F, 0x007F, // Frame 1
    0x001F, 0x041F, 0x041F, 0x041F, 0x001F, 0x001F,
    0x0000, 0x0400, 0x0400, 0x0400, 0x0000, 0x0000 },
  { 0x001F, 0x24DF, 0x1F1F, 0x041F, 0x001F, 0x001F, // Bird
    0xC01F, 0xC41F, 0x843F, 0x843F, 0x007F, 0x007F, // Frame 2
    0x001F, 0x041F, 0x041F, 0x041F, 0x001F, 0x001F,
    0x0000, 0x0400, 0x0400, 0x0400, 0x0000, 0x0000 }
};

UWORD chip ImageData[ARRAYSIZE + 1][SQUAREY * 4] =
{ { 0x7F00, 0xFF80, 0xFF80, 0xFF80, 0x7F00, 0x3E00, // AFFIXER
    0x7F00, 0x9C80, 0xFF80, 0xDD80, 0x6300, 0x3E00,
    0x7F00, 0x9C80, 0xFF80, 0xDD80, 0x6300, 0x3E00,
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F },
  { 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // AMMO
    0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x1C00,
    0x0800, 0x0800, 0x0800, 0x0800, 0x0800, 0x1C00,
    0x087F, 0x007F, 0x087F, 0x007F, 0x087F, 0x007F },
  {	0x0000,	0x0000,	0x0000,	0x6300,	0x0000,	0x0000,		/* ARMOUR */
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80,
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0xFE00,	0xFE00,	0xFC80,	0x3980,	0x9380,	0xC780,		/* BIAS */
	0x0180,	0x0180,	0x0300,	0xC600,	0x6C00,	0x3800,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x0180,	0x0180,	0x0300,	0xC600,	0x6C00,	0x3800 },
  {	0xFB80,	0xF780,	0xFF80,	0xE380,	0xC180,	0xFF80,		/* BOMB */
	0x0600,	0x0800,	0x1C00,	0x6300,	0x4100,	0x3E00,
	0xFF80,	0xF780,	0xE380,	0x9C80,	0xBE80,	0xC180,
	0x0600,	0x0800,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,		/* BONUS */
	0x0180,	0x0180, 0x0300,	0xC600,	0x6C00,	0x3800,
	0x0180,	0x0180,	0x0300,	0xC600,	0x6C00,	0x3800,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x007F,	0x3E7F,	0xC0FF,	0x00FF,	0xC1FF,	0x3E7F,		/* CLOCK */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x3800,	0x0700,	0x3E00,	0x0000,
	0x07FF,	0x007F,	0x007F,	0x007F,	0x007F,	0x007F },
  { 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // CONVERTER
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000,
    0x087F, 0x087F, 0xFFFF, 0x087F, 0x087F, 0x007F,
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000 },
  {     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,         /* CUTTER */
        0x0800, 0x1000, 0x3E00, 0x0400, 0x0800, 0x0000,
        0x0800, 0x1000, 0x3E00, 0x0400, 0x0800, 0x0000,
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {	0x3E00, 0xC180,	0x7F00,	0x1400, 0x0800,	0x0800,         /* CYCLONE */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x3E00,	0xFF80,	0x7F00,	0x1C00,	0x0800,	0x0800,
	0x3E00,	0xFF80,	0x7F00,	0x1C00,	0x0800,	0x0800 },
  { 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // ENCLOSER
    0x0000, 0x1F00, 0x1F00, 0xFF00, 0x1800, 0x1800,
    0x0000, 0x1F00, 0x1F00, 0xFF00, 0x1800, 0x1800,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {	0x8100,	0x7E00,	0x6200,	0x5E00,	0x6000,	0xBE00,         // FREEDOM
	0x7E00,	0x8100,	0x9D00,	0xA100,	0x9E00,	0x4000,
	0xFF00,	0xFF00,	0xFF00,	0xFF00,	0xFE00,	0xFE00,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x3F00,	0x4800,	0x3E00,	0x0900,	0x7E00,	0x0800,		/* GROWER */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
        0x3700,	0x4000,	0x3600, 0x0100,	0x7600,	0x0000 },
  { 0x0000, 0x2100, 0x0000, 0x9C80, 0x0000, 0x4200, // HEALER
    0x0000, 0xA380, 0x0000, 0xDD80, 0x0000, 0xE280,
    0x0000, 0xFF00, 0x0000, 0xFF80, 0x0000, 0x7F80,
    0x007F, 0xA27F, 0x007F, 0x5D7F, 0x007F, 0x22FF },
  {	0x0000,	0x3E00,	0x7C00,	0x7C00,	0x7C00,	0x0000,		/* ICE */
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x3F00,	0x0300,	0x0300,	0x0200,	0x0000,
	0x0000,	0x3F00, 0x0300,	0x0300,	0x0200,	0x0000 },
  {	0x007F,	0x637F,	0x777F,	0x1C7F,	0x087F,	0x007F,		/* LIFE */
	0x6300,	0xF780,	0xFF80,	0x7F00,	0x1C00,	0x0800,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x637F,	0xF7FF,	0xFFFF,	0x7F7F,	0x1C7F,	0x087F },
  {	0x087F,	0x107F,	0x3E7F,	0x047F,	0x087F,	0x007F,		/* LIGHTNING */
	0x0800,	0x1000,	0x3E00,	0x0400,	0x0800,	0x0000,
	0x0800,	0x1000, 0x3E00,	0x0400,	0x0800,	0x0000,
	0x0800,	0x1000,	0x3E00,	0x0400,	0x0800,	0x0000 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x6300,	0x0000,         // MAGNET
	0x0000,	0x3E00,	0x6300,	0x6300,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x3E00,	0x6300,	0x6300,	0x0000,	0x0000 },
  { 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // MISSILE
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000,
    0x087F, 0x087F, 0xFFFF, 0x087F, 0x087F, 0x007F,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {	0xF080,	0xFF00,	0xFE80,	0xFD80,	0xFB80,	0xF000,		/* MULTIPLIER */
	0x0F00,	0x9080,	0x6100,	0x9200,	0x0400,	0x0F80,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0800,	0x1C00,	0x2A00,	0x0800,	0x1C00,	0x0800,		/* NITRO */
	0x0000,	0x0000, 0x0000,	0x0000,	0x1400,	0x1400,
	0x0000,	0x0000,	0x1400,	0x1400, 0x0000,	0x0000,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0xF780,	0xC180,	0x0000,	0x8080,	0xC180,	0xF780,		/* POWER */
	0x0800,	0x3E00,	0xFF80,	0x7F00,	0x3E00,	0x0800,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x0800,	0x0E00,	0x0F80,	0x7800,	0x3800,	0x0800 },
  {	0x0000,	0x6300,	0x0000,	0x2200,	0x1C00,	0x0000,		/* PROTECTOR */
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  { 0x4880, 0x0000, 0x9C00, 0x1C80, 0x0000, 0x8900, // PULSE
    0x48FF, 0x007F, 0x807F, 0x00FF, 0x007F, 0x897F,
    0x4880, 0x0000, 0x8000, 0x0080, 0x0000, 0x8900,
    0x48FF, 0x007F, 0x9C7F, 0x1CFF, 0x007F, 0x897F },
  {	0x0800, 0x3E00, 0xFF80, 0x7F00,	0x3E00,	0x0800,         // PUSHER
	0x0000,	0x3000,	0xF000,	0x0700,	0x0600,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0800,	0x3E00,	0xFF80,	0x7F00,	0x3E00,	0x0800 },
  { 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // REMNANT
    0x0000, 0x0000, 0x1800, 0x1C00, 0x0C00, 0x0000,
    0x007F, 0x007F, 0x187F, 0x187F, 0x007F, 0x007F,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {     0x087F,	0x3E7F, 0xFFFF, 0x7F7F,	0x3E7F,	0x087F,         /* SIDESHOT */
	0x0000,	0x3000,	0xF000,	0x0700,	0x0600,	0x0000,
	0x0800,	0x0E00,	0x0F80,	0x7800,	0x3800,	0x0800,
	0x0800,	0x3E00,	0xFF80,	0x7F00,	0x3E00,	0x0800 },
  {	0xFF80,	0xFF80,	0xE380,	0xE380,	0xFF80,	0xFF80,		/* SLAYER */
	0x4880,	0x0000,	0x9C00,	0x1C80,	0x0000,	0x8900,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,		/* SLOWER */
	0xF800,	0x1F80, 0x2100,	0x4200,	0xFC00,	0x0F80,
	0xF800,	0x1F80,	0x2100,	0x4200,	0xFC00,	0x0F80,
	0x0000,	0x0F80, 0x0100,	0x0200,	0x0400,	0x0F80 },
  {	0x007F,	0x007F,	0x007F,	0x007F,	0x007F,	0x007F,		/* SWITCHER */
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x007F,	0x007F,	0x007F,	0x007F,	0x007F,	0x007F },
  {	0x087F,	0x087F,	0x087F,	0x087F,	0x087F,	0x087F,		/* TREASURE */
	0x3700,	0x4000, 0x3600,	0x0100,	0x7600,	0x0000,
	0x3700,	0x4000,	0x3600,	0x0100, 0x7600,	0x0000,
	0x007F,	0x007F, 0x007F,	0x007F,	0x007F,	0x007F },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,		/* UMBRELLA */
	0x3C00,	0x7E00, 0xFF00,	0x0000,	0x0000,	0x0000,
	0x3C00,	0x7E00,	0xFF00,	0x1000, 0x1000,	0x0C00,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0xFF00,	0x8000,	0x8000,	0x8000,	0x8000,	0x8000,		/* EMPTY */
	0xFF00,	0xFF00, 0xFF00,	0xFF00,	0xFF00,	0x8000,
	0x0000,	0x0000,	0x0000,	0x0000, 0x0000,	0x0000,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0xFF80,	0x8080,	0x8080,	0x8080,	0x8080,	0xFF80,		/* SILVER */
	0x0080,	0x0080, 0x0080,	0x0080,	0x0080,	0x7F80,
	0x0000,	0x7F00,	0x7F00,	0x7F00, 0x7F00,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0xFF80,	0x8080,	0x8080,	0x8080,	0x8080,	0xFF80,		/* GOLD */
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0xFF80,	0xFF80, 0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0xFF00,	0xFF00,	0xFF00,	0xFF00,	0xFF00,	0x8000 },
  {	0x0000,	0x1100,	0xBB80,	0xEE80,	0x5500,	0xFF80,		/* TELEPORT */
	0xFF80,	0xFF80,	0xFF80,	0xEE80,	0x4400,	0x0000,
	0x0000,	0x0000,	0x0000,	0x1100,	0xAA80,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  { 0x007F, 0x007F, 0x187F, 0x187F, 0x007F, 0x007F, // FRAGMENT
    0x0000, 0x0000, 0x0000, 0x0400, 0x0C00, 0x0000,
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {	0x007F,	0x1C7F,	0x3E7F,	0x3E7F,	0x1C7F,	0x007F,		/* ORB */
	0xFF80,	0xFF80, 0xFF80,	0xFE80,	0xFC80,	0xF180,
	0x0000,	0x1C00,	0x3E00,	0x3E00,	0x1C00,	0x0000,
	0x007F,	0x1C7F, 0x3E7F,	0x3E7F,	0x1C7F,	0x007F },
  {	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,		/* Green Protector */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00 },
  {	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,		/* Red Protector */
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00 },
  {	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,		/* Blue Protector */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00 },
  {	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,		/* Yellow Protector */
	0x7F00,	0x9C80, 0xFF80,	0xDD80,	0x6300,	0x3E00,
	0x7F00,	0x9C80,	0xFF80,	0xDD80,	0x6300,	0x3E00,
	0x7F00,	0x9C80, 0xFF80,	0xDD80,	0x6300,	0x3E00 },
  {	0x3F00,		/* Green C */
	0x4000,
	0x4000,
	0x4000,
	0x3F00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0xC080,
	0xA000,
	0x9F80,
	0x9F80,
	0xC080,
	0xE000 },
  {	0x3E00,		/* Red O */
	0x4100,
	0x4100,
	0x4100,
	0x3E00,
	0x0000,
	0xC180,
	0xA080,
	0x9E00,
	0x9E00,
	0xC100,
	0xE080,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0xC180,
	0xA080,
	0x9E00,
	0x9E00,
	0xC100,
	0xE080 },
  {	0x3600,		/* Blue M */
	0x4900,
	0x4900,
	0x4900,
	0x4100,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0xC980,
	0xA480,
	0x9200,
	0x9200,
	0x9A00,
	0xDF00,
	0xC980,
	0xA480,
	0x9200,
	0x9200,
	0x9A00,
	0xDF00 },
  {	0x7E00,		/* Yellow P */
	0x4100,
	0x7E00,
	0x4000,
	0x4000,
	0x0000,
	0x8180,
	0x8080,
	0x8100,
	0x8080,
	0x9F80,
	0xDF80,
	0x8180,
	0x8080,
	0x8100,
	0x8080,
	0x9F80,
	0xDF80,
	0x8180,
	0x8080,
	0x8100,
	0x8080,
	0x9F80,
	0xDF80 },
  {	0x4000,		/* Green L */
	0x4000,
	0x4000,
	0x4000,
	0x7F00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0xBF80,
	0x9F80,
	0x9F80,
	0x9F80,
	0x8080,
	0xC000 },
  {	0x7F00,		/* Red E */
	0x4000,
	0x7800,
	0x4000,
	0x7F00,
	0x0000,
	0x8080,
	0x8000,
	0x8700,
	0x8300,
	0x8000,
	0xC000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x8080,
	0x8000,
	0x8700,
	0x8300,
	0x8000,
	0xC000 },
  {	0x7F00,		/* Blue T */
	0x0800,
	0x0800,
	0x0800,
	0x0800,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x8080,
	0xC000,
	0xF380,
	0xF380,
	0xF380,
	0xFB80,
	0x8080,
	0xC000,
	0xF380,
	0xF380,
	0xF380,
	0xFB80 },
  {	0x7F00,	0x4000,	0x7800,	0x4000,	0x7F00,	0x0000, // Yellow E
        0x8080,	0x8000,	0x8780,	0x8380,	0x8080,	0xC000,
        0x8080,	0x8000,	0x8780,	0x8380, 0x8080, 0xC000,
        0x8080,	0x8000,	0x8780,	0x8380,	0x8080, 0xC000 },
  {	0x3E00, 0x4900,	0x7F00,	0x6300,	0x2200,	0x1C00, /* SKULL */
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,	0x0000, /* SLIME */
	0x4900,	0xAA80, 0x5500,	0x2A00,	0xD500,	0x2A00,
	0x4900,	0xAA80,	0x5500,	0x2A00,	0xD500,	0x2A00,
	0x2200,	0x5500, 0x2A00,	0x5500,	0x2A80,	0x4100 },
  {	0xFF00,	0x8000,	0x8000,	0x8000,	0x8000,	0x8000, /* STONE */
	0xFF80,	0x8080, 0x8080,	0x8080,	0x8080,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000, 0x0000,	0x0000,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {     0xE380, 0xE380, 0xE380, 0x8080, 0x6300, 0x8080, /* GOAT */
	0x1C00,	0x1C00,	0x1C00,	0x7F00,	0x9C80,	0x7F00,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x1C00,	0x1C00,	0x1C00,	0x7F00,	0x9C80,	0x7F00 },
  {	0x0000,	0x7F00,	0x7F00,	0x7F00,	0x7F00,	0x0000, /* WOOD */
	0xFF80,	0xFF80, 0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0xFF00,	0xFF00,	0xFF00,	0xFF00,	0xFF00,	0x8000,
	0xFF00,	0x8000, 0x8000,	0x8000,	0x8000,	0x8000 },
  {	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80, /* Green Tail */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80 },
  {	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80, /* Red Tail */
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80 },
  {	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80, /* Blue Tail */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80 },
  {	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80, /* Yellow Tail */
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80 },
  {     0x8000, 0x5E00, 0x7F80, 0x5E00, 0x8000, 0x0000, // FISH
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0000, 0x0000, 0x0C00, 0x0000, 0x0000, 0x0000,
        0x007F, 0x007F, 0x0C7F, 0x007F, 0x007F, 0x007F },
  { 0x0000, 0x3000, 0x0000, 0x0000, 0x0000, 0x0000, // OTTER
    0x3000, 0x4800, 0x3E00, 0x5500, 0x5500, 0x0000,
    0x3000, 0x4800, 0x3E00, 0x5500, 0x5500, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {     0x0000, 0x0000,	0x1800,	0x1800,	0x0000,	0x0000, /* Green Fire */
        0x0000, 0x0000, 0x0000,	0x0400,	0x0C00,	0x0000,
        0x0000,	0x0000,	0x0000,	0x0000, 0x0000,	0x0000,
        0x0000,	0x0000, 0x1800,	0x1800,	0x0000,	0x0000 },
  {     0x0000,	0x0000,	0x1800,	0x1800,	0x0000,	0x0000, /* Red Fire */
        0x0000,	0x0000, 0x1800,	0x1C00,	0x0C00,	0x0000,
        0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
        0x0000,	0x0000, 0x1800,	0x1800,	0x0000,	0x0000 },
  {     0x0000,	0x0000,	0x1800,	0x1800,	0x0000,	0x0000, /* Blue Fire */
        0x0000,	0x0000, 0x0000,	0x0400,	0x0C00,	0x0000,
        0x0000,	0x0000, 0x1800,	0x1800,	0x0000,	0x0000,
        0x0000,	0x0000,	0x1800,	0x1800,	0x0000,	0x0000 },
  {     0x0000,	0x0000,	0x1800,	0x1800,	0x0000,	0x0000, /* Yellow Fire */
        0x0000,	0x0000, 0x1800,	0x1C00,	0x0C00,	0x0000,
        0x0000,	0x0000,	0x1800,	0x1800, 0x0000,	0x0000,
        0x0000,	0x0000, 0x1800,	0x1800,	0x0000,	0x0000 },
  { 0x087F, 0x087F, 0xFFFF, 0x087F, 0x087F, 0x007F, // Green Missile
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // Frame 0
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x087F, 0x087F, 0xFFFF, 0x087F, 0x087F, 0x007F },
  { 0x087F, 0x087F, 0xFFFF, 0x087F, 0x087F, 0x007F, // Red Missile
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000, // Frame 0
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000 },
  { 0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000, // Blue Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 0
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000,
    0x087F, 0x087F, 0xFFFF, 0x087F, 0x087F, 0x007F },
  { 0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000, // Yellow Missile
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000, // Frame 0
    0x0800, 0x0800, 0xFF80, 0x0800, 0x0800, 0x0000,
    0x087F, 0x087F, 0xFFFF, 0x087F, 0x087F, 0x007F },
  {     0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, /* START */
        0x0000, 0x0000, 0x0380, 0x0380, 0x1C00, 0x1C00,
        0x1C00, 0x1C00, 0x0000, 0x0000, 0x1C00, 0x1C00,
        0x1C00, 0x1C00, 0xE380, 0xE380, 0x1C00, 0x1C00 },
  {     0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // MUSIC
        0x3FFF, 0x20FF, 0x3FFF, 0x20FF, 0xE3FF, 0xE3FF,
        0x3FFF, 0x20FF, 0x3FFF, 0x20FF, 0xE3FF, 0xE3FF,
        0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F },
  {     0xE8FF, 0x857F, 0x827F, 0xE27F, 0x857F, 0x88FF, // FX
        0x0880, 0x0500, 0x0200, 0x0200, 0x0500, 0x0880,
        0xE000, 0x8000, 0x8000, 0xE000, 0x8000, 0x8000,
        0xE880, 0x8500, 0x8200, 0xE200, 0x8500, 0x8880 },
  {	0x7C00,		/* ZERO */
	0x8200,
	0x8200,
	0x8200,
	0x7C00,
	0x0000,
	0x0000,
	0x3C00,
	0x4100,
	0x4100,
	0x0100,
	0x3E00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0x1000,		/* ONE */
	0x3000,
	0x1000,
	0x1000,
	0x3800,
	0x0000,
	0x0000,
	0x0800,
	0x0800,
	0x0800,
	0x0000,
	0x1C00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0xFC00,		/* TWO */
	0x0200,
	0x7C00,
	0x8000,
	0xFE00,
	0x0000,
	0x0000,
	0x7C00,
	0x0100,
	0x3E00,
	0x0000,
	0x7F00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0xFC00,		/* Three */
	0x0200,
	0x1C00,
	0x0200,
	0xFC00,
	0x0000,
	0x0000,
	0x7C00,
	0x0100,
	0x0C00,
	0x0100,
	0x7E00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0x8800,		/* Four */
	0x8800,
	0x8800,
	0xFE00,
	0x0800,
	0x0000,
	0x0000,
	0x4400,
	0x4400,
	0x0000,
	0x7700,
	0x0400,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0xFE00,		/* Five */
	0x8000,
	0xFC00,
	0x0200,
	0xFC00,
	0x0000,
	0x0000,
	0x7F00,
	0x0000,
	0x7C00,
	0x0100,
	0x7E00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0x7E00,		/* Six */
	0x8000,
	0xFC00,
	0x8200,
	0x7C00,
	0x0000,
	0x0000,
	0x3F00,
	0x0000,
	0x7C00,
	0x0100,
	0x3E00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0xFC00,		/* Seven */
	0x0400,
	0x0800,
	0x1000,
	0x2000,
	0x0000,
	0x0000,
	0x7A00,
	0x0200,
	0x0400,
	0x0800,
	0x1000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0x7C00,		/* Eight */
	0x8200,
	0x7C00,
	0x8200,
	0x7C00,
	0x0000,
	0x0000,
	0x3C00,
	0x0100,
	0x3C00,
	0x0100,
	0x3E00,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0x7C00,		/* Nine */
	0x8200,
	0x7E00,
	0x0200,
	0x0200,
	0x0000,
	0x0000,
	0x3C00,
	0x0100,
	0x3D00,
	0x0100,
	0x0100,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000,
	0x0000 },
  {	0x1C00,	0x3E00,	0x7F00,	0xFF80,	0x9C80,	0xFF80,		/* GREENHEADUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80 },
  {	0x1C00,	0x3E00, 0x7F00,	0xFF80,	0x9C80,	0xFF80,		/* REDHEADUP */
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80 },
  {	0x1C00,	0x3E00,	0x7F00,	0xFF80,	0x9C80,	0xFF80,		/* BLUEHEADUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80,
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80 },
  {	0x1C00,	0x3E00,	0x7F00,	0xFF80,	0x9C80,	0xFF80,		/* YELLOWHEADUP */
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80,
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80,
	0x1C00,	0x3E00,	0x7F00,	0x9C80,	0x9C80,	0xFF80 },
  {	0xFF80,	0x9C80,	0xFF00,	0x7F00,	0x3E00,	0x1C00,		/* GREENHEADDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x9C80,	0x9C00,	0x7F00,	0x3E00,	0x1C00 },
  {	0xFF80,	0x9C80,	0xFF80,	0x7F00,	0x3E00,	0x1C00,		/* REDHEADDOWN */
	0xFF80,	0x9C80,	0x9C80,	0x7F00,	0x3E00,	0x1C00,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x9C80,	0x9C80,	0x7F00,	0x3E00,	0x1C00 },
  {	0xFF80,	0x9C80, 0xFF80,	0x7F00,	0x3E00,	0x1C00,		/* BLUEHEADDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x9C80,	0x9C80,	0x7F00,	0x3E00,	0x1C00,
	0xFF80,	0x9C80,	0x9C80,	0x7F00,	0x3E00,	0x1C00 },
  {	0xFF80,	0x9C80,	0xFF80,	0x7F00,	0x3E00,	0x1C00,		/* YELLOWHEADDOWN */
	0xFF80,	0x9C80,	0x9C80,	0x7F00,	0x3E00,	0x1C00,
	0xFF80,	0x9C80,	0x9C80,	0x7F00,	0x3E00,	0x1C00,
	0xFF80,	0x9C80,	0x9C80,	0x7F00,	0x3E00,	0x1C00 },
  {	0x0F80,	0x3C80,	0xFF80,	0xFF80,	0x3C80,	0x0F80,		/* GREENHEADLEFT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80 },
  {	0x0F80,	0x3C80,	0xFF80,	0xFF80,	0x3C80,	0x0F80,		/* REDHEADLEFT */
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80 },
  {	0x0F80,	0x3C80,	0xFF80,	0xFF80,	0x3C80,	0x0F80,		/* BLUEHEADLEFT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80,
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80 },
  {	0x0F80,	0x3C80,	0xFF80,	0xFF80,	0x3C80,	0x0F80,		/* YELLOWHEADLEFT */
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80,
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80,
	0x0F80,	0x3080,	0xFF80,	0xFF80,	0x3080,	0x0F80 },
  {	0xF800,	0x9E00,	0xFF80,	0xFF80,	0x9E00,	0xF800,		/* GREENHEADRIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xF800,	0x8600,	0xFF80,	0xFF80,	0x8600,	0xF800 },
  {	0xF800,	0x9E00,	0xFF80,	0xFF80,	0x9E00,	0xF800,		/* REDHEADRIGHT */
	0xF800,	0x8600, 0xFF80,	0xFF80,	0x8600,	0xF800,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xF800,	0x8600,	0xFF80,	0xFF80,	0x8600,	0xF800 },
  {	0xF800,	0x9E00,	0xFF80,	0xFF80,	0x9E00,	0xF800,		/* BLUEHEADRIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xF800,	0x8600,	0xFF80,	0xFF80,	0x8600,	0xF800,
	0xF800,	0x8600,	0xFF80,	0xFF80,	0x8600,	0xF800 },
  {	0xF800,	0x9E00,	0xFF80,	0xFF80,	0x9E00,	0xF800,		/* YELLOWHEADRIGHT */
	0xF800,	0x8600,	0xFF80,	0xFF80,	0x8600,	0xF800,
	0xF800,	0x8600,	0xFF80,	0xFF80,	0x8600,	0xF800,
	0xF800,	0x8600,	0xFF80,	0xFF80,	0x8600,	0xF800 },
  {	0x8080,	0xC180,	0xF780,	0xFF80,	0x9C80,	0xFF80,		/* GREENMODEUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80 },
  {	0x8080,	0xC180,	0xF780,	0xFF80,	0x9C80,	0xFF80,		/* REDMODEUP */
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80 },
  {	0x8080,	0xC180,	0xF780,	0xFF80,	0x9C80,	0xFF80,		/* BLUEMODEUP */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80,
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80 },
  {	0x8080,	0xC180,	0xF780,	0xFF80,	0x9C80,	0xFF80,		/* YELLOWMODEUP */
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80,
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80, 0xFF80,
	0x8080,	0xC180,	0xF780,	0x9C80,	0x9C80,	0xFF80 },
  {	0xFF80,	0x9C80,	0xFF80,	0xF780,	0xC180,	0x8080,		/* GREENMODEDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080 },
  {	0xFF80,	0x9C80,	0xFF80,	0xF780,	0xC180,	0x8080,		/* REDMODEDOWN */
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080 },
  {	0xFF80,	0x9C80,	0xFF80,	0xF780,	0xC180,	0x8080,		/* BLUEMODEDOWN */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080,
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080 },
  {	0xFF80,	0x9C80,	0xFF80,	0xF780,	0xC180,	0x8080,		/* YELLOWMODEDOWN */
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080,
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080,
	0xFF80,	0x9C80,	0x9C80,	0xF780,	0xC180,	0x8080 },
  {	0xFF80, 0x7C80, 0x1F80,	0x1F80,	0x7C80,	0xFF80,		/* GREENMODELEFT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x7080, 0x1F80,	0x1F80,	0x7080,	0xFF80 },
  {	0xFF80,	0x7C80,	0x1F80,	0x1F80,	0x7C80,	0xFF80,		/* REDMODELEFT */
	0xFF80,	0x7080,	0x1F80,	0x1F80,	0x7080,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x7080, 0x1F80,	0x1F80,	0x7080,	0xFF80 },
  {	0xFF80,	0x7C80,	0x1F80,	0x1F80,	0x7C80,	0xFF80,		/* BLUEMODELEFT */
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x7080,	0x1F80,	0x1F80, 0x7080,	0xFF80,
	0xFF80,	0x7080, 0x1F80,	0x1F80,	0x7080,	0xFF80 },
  {	0xFF80,	0x7C80,	0x1F80,	0x1F80,	0x7C80,	0xFF80,		/* YELLOWMODELEFT */
	0xFF80,	0x7080, 0x1F80,	0x1F80,	0x7080,	0xFF80,
	0xFF80,	0x7080,	0x1F80,	0x1F80,	0x7080,	0xFF80,
	0xFF80,	0x7080, 0x1F80,	0x1F80,	0x7080,	0xFF80 },
  {	0xFF80,	0x9F00,	0xFC00,	0xFC00,	0x9F00,	0xFF80,		/* GREENMODERIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x8700, 0xFC00,	0xFC00,	0x8700,	0xFF80 },
  {	0xFF80,	0x9F00,	0xFC00,	0xFC00,	0x9F00,	0xFF80,		/* REDMODERIGHT */
	0xFF80,	0x8700, 0xFC00,	0xFC00,	0x8700,	0xFF80,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x8700, 0xFC00,	0xFC00,	0x8700,	0xFF80 },
  {	0xFF80,	0x9F00,	0xFC00,	0xFC00,	0x9F00,	0xFF80,		/* BLUEMODERIGHT */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0x8700, 0xFC00,	0xFC00,	0x8700,	0xFF80,
	0xFF80,	0x8700,	0xFC00,	0xFC00,	0x8700,	0xFF80 },
  {	0xFF80,	0x9F00,	0xFC00,	0xFC00,	0x9F00,	0xFF80,		/* YELLOWMODERIGHT */
	0xFF80,	0x8700,	0xFC00,	0xFC00,	0x8700,	0xFF80,
	0xFF80,	0x8700,	0xFC00,	0xFC00,	0x8700,	0xFF80,
	0xFF80,	0x8700,	0xFC00,	0xFC00,	0x8700,	0xFF80 },
  {	0x0000, 0x7F00,	0x7F00,	0x7F00,	0x7F00,	0x0000,		/* METAL */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,
	0x0080,	0x7F80,	0x7F80,	0x7F80,	0x7F80,	0x7F80 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,		/* Green Drip */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,		/* Red Drip */
	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,		/* Blue Drip */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00,
	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00 },
  {	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00,		/* Yellow Drip */
	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00,
	0x0800,	0x0800,	0x1C00,	0x3E00,	0x3E00,	0x1C00,
	0x0800,	0x0800,	0x1C00,	0x3E00, 0x3E00,	0x1C00 },
  { 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // BLACKENED
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F },
  {	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,	0xFF80,		/* WHITENED */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0F80, 0xF980,	0x0F80,	0x1F80,	0x0000,	0x0000,		/* PENGUIN */
	0x0000,	0xF000,	0xF000,	0x0000,	0x3980,	0x7180,
	0x0800,	0xF800,	0xFF80,	0x1F80,	0x3980,	0x7180,
	0x0800,	0xF800,	0xFF80,	0x1F80,	0x0000,	0x0000 },
  {	0x3E00,	0xC180,	0x7F00,	0x1400,	0x0800,	0x0800,         /* WHIRLWIND */
        0x3E00,	0xFF80,	0x7F00,	0x1C00,	0x0800,	0x0800,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
        0x3E00,	0xFF80, 0x7F00,	0x1C00,	0x0800,	0x0800 },
  {	0x0A00,	0x0780,	0x9C00,	0x7C00,	0xAA00,	0x0000,         /* DOG (chasing) */
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,         /* DOGAWAKENING */
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
	0x0A00,	0x0780,	0x9C00,	0x7C00,	0xAA00,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x0A00,	0x0780,	0x9C00,	0x7C00,	0xAA00,	0x0000,         /* DOGDORMANT */
        0x0A00,	0x0780, 0x9C00,	0x7C00,	0xAA00,	0x0000,
	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,	0x0000,
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000 },
  {	0x007F, 0x3E7F,	0xFFFF,	0x3E7F,	0x007F,	0x007F,         /* CLOUD */
        0x0000,	0x0000, 0x0000,	0x0000,	0x0000,	0x0000,
	0x0000,	0x1C00,	0xE380,	0x1C00, 0x0000,	0x0000,
        0x007F,	0x1C7F, 0xE3FF,	0x1C7F,	0x007F, 0x007F },
  {     0x0800, 0xEB80, 0x1C00, 0x1C00, 0xEB80, 0x0800, /* ALL */
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000 },
  {     0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000, /* Green Arrow */
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000 },
  {     0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000, /* Red Arrow */
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000,
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000 },
  {     0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000, /* Blue Arrow */
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000,
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000 },
  {     0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000, /* Yellow Arrow */
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000,
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000,
        0x0C00, 0x3000, 0xFF80, 0x3000, 0x0C00, 0x0000 },
  {     0xFF80, 0xFF80, 0xFF80, 0xFF80, 0xFF80, 0xFF80, // DYNAMITE
        0x0000, 0x0000, 0x3E00, 0x3E00, 0x0000, 0x0000,
        0x0000, 0x7F00, 0x7F00, 0x7F00, 0x7F00, 0x0000,
        0xFF80, 0xFF80, 0xFF80, 0xFF80, 0xFF80, 0xFF80 },
  {     0xDD80, 0x3E00, 0xFF80, 0x3E00, 0xDD80, 0x1C00, // OCTOPUS
        0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
        0x0000, 0x0000, 0x3600, 0x0000, 0x0000, 0x0000,
        0x007F, 0x007F, 0x367F, 0x007F, 0x007F, 0x007F },
  { 0x047F, 0x887F, 0x7F7F, 0x08FF, 0x107F, 0x007F, // Green Missile
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // Frame 1
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x047F, 0x887F, 0x7F7F, 0x08FF, 0x107F, 0x007F },
  { 0x827F, 0x647F, 0x1C7F, 0x137F, 0x20FF, 0x007F, // Green Missile
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // Frame 2
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x827F, 0x647F, 0x1C7F, 0x137F, 0x20FF, 0x007F },
  { 0x417F, 0x367F, 0x087F, 0x367F, 0x417F, 0x007F, // Green Missile
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F, // Frame 3
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x417F, 0x367F, 0x087F, 0x367F, 0x417F, 0x007F },
  { 0x20FF, 0x137F, 0x1C7F, 0x647F, 0x827F, 0x007F, // Green Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 4
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000 },
  { 0x107F, 0x08FF, 0x7F7F, 0x887F, 0x047F, 0x007F, // Green Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 5
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000,
    0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000 },
  { 0x047F, 0x887F, 0x7F7F, 0x08FF, 0x107F, 0x007F, // Red Missile
    0x0400, 0x8800, 0x7F00, 0x0880, 0x1000, 0x0000, // Frame 1
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x0400, 0x8800, 0x7F00, 0x0880, 0x1000, 0x0000 },
  { 0x827F, 0x647F, 0x1C7F, 0x137F, 0x20FF, 0x007F, // Red Missile
    0x8200, 0x6400, 0x1C00, 0x1300, 0x2080, 0x0000, // Frame 2
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x8200, 0x6400, 0x1C00, 0x1300, 0x2080, 0x0000 },
  { 0x417F, 0x367F, 0x087F, 0x367F, 0x417F, 0x007F, // Red Missile
    0x4100, 0x3600, 0x0800, 0x3600, 0x4100, 0x0000, // Frame 3
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x4100, 0x3600, 0x0800, 0x3600, 0x4100, 0x0000 },
  { 0x20FF, 0x137F, 0x1C7F, 0x647F, 0x827F, 0x007F, // Red Missile
    0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000, // Frame 4
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000 },
  { 0x107F, 0x08FF, 0x7F7F, 0x887F, 0x047F, 0x007F, // Red Missile
    0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000, // Frame 5
    0x007F, 0x007F, 0x007F, 0x007F, 0x007F, 0x007F,
    0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000 },
  { 0x0400, 0x8800, 0x7F00, 0x0880, 0x1000, 0x0000, // Blue Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 1
    0x0400, 0x8800, 0x7F00, 0x0880, 0x1000, 0x0000,
    0x047F, 0x887F, 0x7F7F, 0x08FF, 0x107F, 0x007F },
  { 0x8200, 0x6400, 0x1C00, 0x1300, 0x2080, 0x0000, // Blue Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 2
    0x8200, 0x6400, 0x1C00, 0x1300, 0x2080, 0x0000,
    0x827F, 0x647F, 0x1C7F, 0x137F, 0x20FF, 0x007F },
  { 0x4100, 0x3600, 0x0800, 0x3600, 0x4100, 0x0000, // Blue Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 3
    0x4100, 0x3600, 0x0800, 0x3600, 0x4100, 0x0000,
    0x417F, 0x367F, 0x087F, 0x367F, 0x417F, 0x007F },
  { 0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000, // Blue Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 4
    0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000,
    0x20FF, 0x137F, 0x1C7F, 0x647F, 0x827F, 0x007F },
  { 0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000, // Blue Missile
    0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, // Frame 5
    0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000,
    0x107F, 0x08FF, 0x7F7F, 0x887F, 0x047F, 0x007F },
  { 0x0400, 0x8800, 0x7F00, 0x0880, 0x1000, 0x0000, // Yellow Missile
    0x0400, 0x8800, 0x7F00, 0x0880, 0x1000, 0x0000, // Frame 1
    0x0400, 0x8800, 0x7F00, 0x0880, 0x1000, 0x0000,
    0x047F, 0x887F, 0x7F7F, 0x08FF, 0x107F, 0x007F },
  { 0x8200, 0x6400, 0x1C00, 0x1300, 0x2080, 0x0000, // Yellow Missile
    0x8200, 0x6400, 0x1C00, 0x1300, 0x2080, 0x0000, // Frame 2
    0x8200, 0x6400, 0x1C00, 0x1300, 0x2080, 0x0000,
    0x827F, 0x647F, 0x1C7F, 0x137F, 0x20FF, 0x007F },
  { 0x4100, 0x3600, 0x0800, 0x3600, 0x4100, 0x0000, // Yellow Missile
    0x4100, 0x3600, 0x0800, 0x3600, 0x4100, 0x0000, // Frame 3
    0x4100, 0x3600, 0x0800, 0x3600, 0x4100, 0x0000,
    0x417F, 0x367F, 0x087F, 0x367F, 0x417F, 0x007F },
  { 0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000, // Yellow Missile
    0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000, // Frame 4
    0x2080, 0x1300, 0x1C00, 0x6400, 0x8200, 0x0000,
    0x20FF, 0x137F, 0x1C7F, 0x647F, 0x827F, 0x007F },
  { 0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000, // Yellow Missile
    0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000, // Frame 5
    0x1000, 0x0880, 0x7F00, 0x8800, 0x0400, 0x0000,
    0x107F, 0x08FF, 0x7F7F, 0x887F, 0x047F, 0x007F },
  { 0x007F, 0x087F, 0x3E7F, 0xC9FF, 0x007F, 0x007F, // BIRD
    0x0000, 0x0800, 0x0800, 0x0800, 0x0000, 0x0000, // Frame 0
    0x0000, 0x0800, 0x0800, 0x0800, 0x0000, 0x0000,
    0x007F, 0x087F, 0x087F, 0x087F, 0x007F, 0x007F },
  { 0x0000, 0x0800, 0xFF80, 0x0800, 0x0000, 0x0000, // Bird
    0x0000, 0x0800, 0x0800, 0x0800, 0x0000, 0x0000, // Frame 1
    0x0000, 0x0800, 0x0800, 0x0800, 0x0000, 0x0000,
    0x007F, 0x087F, 0x087F, 0x087F, 0x007F, 0x007F },
  { 0x0000, 0xC980, 0x3E00, 0x0800, 0x0000, 0x0000, // Bird
    0x0000, 0x0800, 0x0800, 0x0800, 0x0000, 0x0000, // Frame 2
    0x0000, 0x0800, 0x0800, 0x0800, 0x0000, 0x0000,
    0x007F, 0x087F, 0x087F, 0x087F, 0x007F, 0x007F }
};

UWORD chip LogoData[3240] =
	{
	/* Plane 0 */
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xE000,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0600,0x0000,0x0001,0x8000,0x0000,0x0018,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0600,0x6006,0x0006,0x1E00,0x0000,0x7861,0x8180,0x01E1,0x8018,0x1800,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0660,0x6606,0x0018,0x1800,0x0007,0xE187,0x8180,0x1F87,0x8078,0x1800,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0600,0x6006,0x0060,0x1800,0x001E,0x061E,0x0780,0x781E,0x01E0,0x1800,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0600,0x6006,0x0060,0x1800,0x1800,0x0018,0x1E00,0x0018,0x0180,0x1800,0x0000,0x0000,0x7F80,0x7800,
	0xC000,0x0600,0x6006,0x0060,0x1800,0x1800,0x0018,0x7800,0x0018,0x0000,0x1800,0x0000,0x001F,0xF800,0x7800,
	0xC000,0x0600,0x6006,0x0060,0x1800,0x1800,0x0001,0xE000,0x0018,0x0078,0x1800,0x0000,0x01FE,0x0000,0x7800,
	0xC01E,0x0600,0x6006,0x0060,0x1800,0x1800,0x0018,0x0000,0x0018,0x01E0,0x1800,0x0000,0x07E0,0x0000,0x7800,
	0xC000,0x0600,0x6006,0x0060,0x1800,0x1800,0x0019,0x8000,0x0018,0x0180,0x1800,0x0000,0x1F80,0x0000,0x7800,
	0xC000,0x0600,0x6006,0x0000,0x1800,0x1800,0x1818,0x0180,0x0019,0x8180,0x1800,0x0000,0x7E00,0x0000,0x7800,
	0xC000,0x1E00,0x001E,0x0000,0x7800,0x7800,0x7878,0x0180,0x0078,0x0180,0x1800,0x0001,0xF800,0x0000,0x7800,
	0xC000,0x0000,0x1878,0x0000,0x6001,0xE000,0x01E0,0x0000,0x0000,0x0000,0x0000,0x0001,0xE000,0x0000,0x7800,
	0xC001,0x8018,0x01E0,0x0000,0x0007,0x8001,0x8000,0x01E0,0x0600,0x0180,0x1E00,0x0007,0xE000,0x0000,0x7800,
	0xC007,0x8078,0x0780,0x0006,0x007E,0x0007,0x9807,0x8780,0x1E60,0x0798,0x7800,0x0007,0x8000,0x0000,0x7800,
	0xC006,0x07E0,0x7E00,0x0000,0x7FE0,0x0006,0x01FE,0x1E00,0x1807,0xFE01,0xE000,0x001E,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC007,0xE000,0x0000,0x0000,0x0000,0x0007,0xE000,0x0000,0x1F80,0x0000,0x0000,0x0001,0xF800,0x1800,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x001F,0xE000,0x0600,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x007E,0x0000,0x0780,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0078,0x0000,0x0180,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0078,0x0000,0x01E0,0x7800,
	0xC000,0x0600,0x0000,0x0000,0x0000,0x1800,0x0018,0x0000,0x0000,0x0001,0xE000,0x0078,0x0000,0x01E0,0x7800,
	0xC000,0x0600,0x6006,0x0000,0x1FE0,0x1800,0x7861,0x8180,0x0000,0x0007,0x8000,0x0078,0x0000,0x01E0,0x7800,
	0xC000,0x0660,0x6606,0x0000,0x6000,0x1807,0xE187,0x8180,0x001F,0x807E,0x0000,0x0078,0x0000,0x01E0,0x7800,
	0xC000,0x0600,0x6006,0x0001,0x8018,0x181E,0x061E,0x0780,0x0000,0x1FE0,0x0000,0x0078,0x0000,0x01E0,0x7800,
	0xC000,0x0600,0x6006,0x0001,0x9878,0x1800,0x0018,0x1E00,0x0000,0x0000,0x0000,0x0078,0x0000,0x01E0,0x7800,
	0xC000,0x0600,0x6006,0x0000,0x01E0,0x1800,0x0018,0x7800,0x0060,0x0000,0x0000,0x0018,0x0000,0x07E0,0x7800,
	0xC000,0x0600,0x6006,0x0000,0x0780,0x1800,0x0001,0xE000,0x0006,0x0000,0x0000,0x001E,0x0000,0x0780,0x7800,
	0xC01E,0x0600,0x6006,0x0000,0x1E00,0x1800,0x0018,0x0000,0x0060,0x6000,0x0000,0x0006,0x0000,0x0780,0x7800,
	0xC000,0x0600,0x6006,0x0000,0x0000,0x1800,0x0019,0x8000,0x0006,0x0600,0x0000,0x0007,0x8000,0x1F80,0x7800,
	0xC000,0x0600,0x6006,0x0001,0xFFF8,0x1800,0x1818,0x0180,0x0000,0x6001,0x8000,0x0000,0x0000,0x7E00,0x7800,
	0xC000,0x1E00,0x001E,0x0007,0x8000,0x1800,0x7878,0x0180,0x0000,0x0787,0x8000,0x0000,0x0001,0xF800,0x7800,
	0xC000,0x0000,0x1878,0x0000,0x0000,0x1800,0x01E0,0x0000,0x01F8,0x001E,0x0000,0x0000,0x001F,0xE000,0x7800,
	0xC001,0x8018,0x01E0,0x01F8,0x0078,0x0001,0x8000,0x01E0,0x0781,0x8078,0x0000,0x0000,0x7FFE,0x0000,0x7800,
	0xC007,0x8078,0x0780,0x0180,0x01E0,0x1E07,0x9807,0x8780,0x0000,0x01E0,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC006,0x07E0,0x7E00,0x0000,0x7F80,0x7806,0x01FE,0x1E00,0x0600,0x0780,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x01F8,0x0000,0x0000,0x0000,0x0000,0x007F,0x8000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC007,0xE000,0x0000,0x0000,0x0000,0x0007,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7800,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF800,
	0xFFFF,0xFFFF,0xFFFF,0xC199,0xFF0E,0x3198,0x30CE,0x7FC1,0x8604,0x0999,0x860C,0x0FFF,0xFFFF,0xFFFF,0xF800,
	0xFFFF,0xFFFF,0xFFFF,0xCC99,0xFE64,0xCC93,0xE646,0x7F9F,0x327F,0x3999,0x3264,0xFFFF,0xFFFF,0xFFFF,0xF800,
	0xFFFF,0xFFFF,0xFFFF,0xC1C1,0xFE04,0xCC92,0x204A,0x7FC3,0x320F,0x3999,0x020C,0x1FFF,0xFFFF,0xFFFF,0xF800,
	0xFFFF,0xFFFF,0xFFFF,0xCCF9,0xFE64,0xCC93,0x264C,0x7FF9,0x327F,0x3999,0x324C,0xFFFF,0xFFFF,0xFFFF,0xF800,
	0xFFFF,0xFFFF,0xFFFF,0xC1C3,0xFE64,0xCC98,0x264E,0x7F83,0x867F,0x3C63,0x3264,0x0FFF,0xFFFF,0xFFFF,0xF800,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF800,
	0x3FFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF800,
	/* Plane 1 */
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0007,0x9FE0,0x0000,0x0000,0x0000,0x07F8,0x7807,0x8000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x001E,0x7FF8,0x0000,0x0000,0x0000,0x1FFF,0xFE7F,0xE000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0079,0xE1FE,0x0000,0x0000,0x0000,0x7E1E,0x7FE7,0xE000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x01E7,0xE07F,0x8000,0x0000,0x0001,0xE078,0x7F87,0xE000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x079F,0xE01F,0xE000,0x0000,0x0000,0x01E0,0x7E07,0xE000,0x0000,0x007F,0xF800,0x1800,
	0x0000,0x0000,0x0000,0x1F87,0xE007,0xE000,0x0000,0x0000,0x07E0,0x7E07,0xE000,0x0000,0x1FFF,0x8000,0x1800,
	0x0000,0x0000,0x0000,0x1F87,0xE007,0xE000,0x0000,0x0000,0x07E0,0x7FE7,0xE000,0x0000,0x7FE0,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x1F87,0xE007,0xE000,0x0000,0x0000,0x07E0,0x7F87,0xE000,0x0007,0xFE00,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x1F87,0xE007,0xE000,0x0000,0x0000,0x07E1,0xFE07,0xE000,0x001F,0xF800,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x1F87,0xE007,0xE000,0x0000,0x0000,0x07E7,0xFE07,0xE000,0x007F,0xE000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x07E7,0xE007,0xE000,0x0000,0x0000,0x07E0,0x7E07,0xE000,0x01FF,0x8000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x01FF,0x8007,0x8000,0x0000,0x0000,0x0780,0x7E07,0xE000,0x07FE,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x007F,0x801E,0x0000,0x0000,0x0000,0x1FF8,0x7FE7,0xF800,0x1FFE,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x001F,0xFFF8,0x0000,0x0000,0x0000,0x79FF,0xFE7F,0xE000,0x1FF8,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0001,0xFF80,0x0000,0x0000,0x0001,0xE01F,0xF807,0x8000,0x7FF8,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xE000,0x0000,0x0000,0x7FE1,0xFFF8,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7E00,0x0000,0x0000,0x7FFF,0xFFFF,0x8000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7FFE,0x07FF,0xE000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFFE0,0x007F,0xF800,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x007F,0xF800,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x001F,0xFE00,0x1800,
	0x0000,0x781E,0x01E0,0x0000,0x0000,0x0000,0x7FF9,0xF800,0x0000,0x0000,0x0001,0xFF80,0x001F,0xFE00,0x1800,
	0x0001,0xF87F,0x87F8,0x0000,0x0000,0x0007,0xFFE7,0xFE00,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x1800,
	0x0007,0xF9FF,0x9FF8,0x0000,0x0000,0x001F,0x879E,0x7E00,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x1800,
	0x0001,0xF81F,0x81F8,0x0000,0x0000,0x0078,0x1E78,0x7E00,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x1800,
	0x0001,0xF81F,0x81F8,0x0000,0x0000,0x0000,0x79E0,0x7800,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x1800,
	0x0001,0xF81F,0x81F8,0x0000,0x0000,0x0001,0xFFE1,0xE000,0x0000,0x0000,0x0000,0x7F80,0x0007,0xFE00,0x1800,
	0x001F,0xF81F,0x81F8,0x0000,0x0000,0x0001,0xFFE7,0x8000,0x0000,0x0000,0x0000,0x7FE0,0x0007,0xF800,0x1800,
	0x007F,0xF81F,0x81F8,0x0000,0x0000,0x0001,0xFFFE,0x0000,0x0000,0x0000,0x0000,0x7FE0,0x001F,0xF800,0x1800,
	0x0001,0xF81F,0x81F8,0x0000,0x0000,0x0001,0xFFE7,0xF800,0x0000,0x0000,0x0000,0x1FF8,0x001F,0xF800,0x1800,
	0x0001,0xF81F,0x81F8,0x0000,0x0000,0x0001,0xFFE0,0x7E00,0x0000,0x0000,0x0000,0x07F8,0x007F,0xE000,0x1800,
	0x0001,0xF81F,0x81F8,0x0000,0x0000,0x0001,0xE7E0,0x7E00,0x0000,0x0000,0x0000,0x01FF,0x81FF,0x8000,0x1800,
	0x0001,0xE01F,0xE1E0,0x0000,0x0000,0x0000,0x0780,0x7E00,0x0000,0x0000,0x0000,0x007F,0xFFFE,0x0000,0x1800,
	0x0007,0xFE7F,0xE780,0x0000,0x0000,0x0007,0xFE00,0x7F80,0x0000,0x0000,0x0000,0x0007,0xFFE0,0x0000,0x1800,
	0x001E,0x7FE7,0xFE00,0x0000,0x0000,0x001E,0x7F9E,0x7E00,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0078,0x1F81,0xF800,0x0000,0x0000,0x0078,0x07F8,0x7800,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0078,0x0000,0x0000,0x0000,0x0000,0x0078,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x001F,0x8000,0x0000,0x0000,0x0000,0x001F,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xF800,
	/* Plane 2 */
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7FF9,0xF800,0x07F8,0x7807,0x8000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0007,0xFFE7,0xFE00,0x1FFF,0xFE7F,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x001F,0x879E,0x7E00,0x7E1E,0x7FE7,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0078,0x1E78,0x7E01,0xE078,0x7F87,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x79E0,0x7800,0x01E0,0x7E07,0xE000,0x0000,0x007F,0xF800,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFFE1,0xE000,0x07E0,0x7E07,0xE000,0x0000,0x1FFF,0x8000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFFE7,0x8000,0x07E0,0x7FE7,0xE000,0x0000,0x7FE0,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFFFE,0x0000,0x07E0,0x7F87,0xE000,0x0007,0xFE00,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFFE7,0xF800,0x07E1,0xFE07,0xE000,0x001F,0xF800,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFFE0,0x7E00,0x07E7,0xFE07,0xE000,0x007F,0xE000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xE7E0,0x7E00,0x07E0,0x7E07,0xE000,0x01FF,0x8000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0780,0x7E00,0x0780,0x7E07,0xE000,0x07FE,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0007,0xFE00,0x7F80,0x1FF8,0x7FE7,0xF800,0x1FFE,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x001E,0x7F9E,0x7E00,0x79FF,0xFE7F,0xE000,0x1FF8,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0078,0x07F8,0x7801,0xE01F,0xF807,0x8000,0x7FF8,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0078,0x0000,0x0001,0xE000,0x0000,0x0000,0x7FE1,0xFFF8,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x001F,0x8000,0x0000,0x7E00,0x0000,0x0000,0x7FFF,0xFFFF,0x8000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7FFE,0x07FF,0xE000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFFE0,0x007F,0xF800,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x007F,0xF800,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x001F,0xFE00,0x0000,
	0x0000,0x781E,0x01E0,0x0000,0x1FF9,0xE000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x001F,0xFE00,0x0000,
	0x0001,0xF87F,0x87F8,0x0001,0xFFFF,0xE000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x0000,
	0x0007,0xF9FF,0x9FF8,0x0007,0xE01F,0xE000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x0000,
	0x0001,0xF81F,0x81F8,0x001F,0x9FFF,0xE000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x0000,
	0x0001,0xF81F,0x81F8,0x001E,0x7FE7,0xE000,0x0000,0x0000,0x0000,0x0000,0x0001,0xFF80,0x0007,0xFE00,0x0000,
	0x0001,0xF81F,0x81F8,0x001E,0x0787,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7F80,0x0007,0xFE00,0x0000,
	0x001F,0xF81F,0x81F8,0x0007,0x9E07,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7FE0,0x0007,0xF800,0x0000,
	0x007F,0xF81F,0x81F8,0x0001,0xF807,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x7FE0,0x001F,0xF800,0x0000,
	0x0001,0xF81F,0x81F8,0x0001,0xE007,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1FF8,0x001F,0xF800,0x0000,
	0x0001,0xF81F,0x81F8,0x0007,0xFFFF,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x07F8,0x007F,0xE000,0x0000,
	0x0001,0xF81F,0x81F8,0x001E,0x0007,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x01FF,0x81FF,0x8000,0x0000,
	0x0001,0xE01F,0xE1E0,0x0078,0x0007,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x007F,0xFFFE,0x0000,0x0000,
	0x0007,0xFE7F,0xE780,0x07FF,0x81FF,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0007,0xFFE0,0x0000,0x0000,
	0x001E,0x7FE7,0xFE00,0x1E07,0xFF87,0xF800,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0078,0x1F81,0xF800,0x1E01,0xFE01,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0078,0x0000,0x0000,0x07E0,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x001F,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	/* Plane 3 */
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1800,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x781E,0x01E0,0x0007,0x9FE0,0x0000,0x7FF9,0xF800,0x07F8,0x7807,0x8000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF87F,0x87F8,0x001E,0x7FF8,0x0007,0xFFE7,0xFE00,0x1FFF,0xFE7F,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0007,0xF9FF,0x9FF8,0x0079,0xE1FE,0x001F,0x879E,0x7E00,0x7E1E,0x7FE7,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x01E7,0xE07F,0x8078,0x1E78,0x7E01,0xE078,0x7F87,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x079F,0xE01F,0xE000,0x79E0,0x7800,0x01E0,0x7E07,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x1F87,0xE007,0xE001,0xFFE1,0xE000,0x07E0,0x7E07,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x001F,0xF81F,0x81F8,0x1F87,0xE007,0xE001,0xFFE7,0x8000,0x07E0,0x7FE7,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x007F,0xF81F,0x81F8,0x1F87,0xE007,0xE001,0xFFFE,0x0000,0x07E0,0x7F87,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x1F87,0xE007,0xE001,0xFFE7,0xF800,0x07E1,0xFE07,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x1F87,0xE007,0xE001,0xFFE0,0x7E00,0x07E7,0xFE07,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x07E7,0xE007,0xE001,0xE7E0,0x7E00,0x07E0,0x7E07,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xE01F,0xE1E0,0x01FF,0x8007,0x8000,0x0780,0x7E00,0x0780,0x7E07,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0007,0xFE7F,0xE780,0x007F,0x801E,0x0007,0xFE00,0x7F80,0x1FF8,0x7FE7,0xF800,0x0000,0x0000,0x0000,0x0000,
	0x001E,0x7FE7,0xFE00,0x001F,0xFFF8,0x001E,0x7F9E,0x7E00,0x79FF,0xFE7F,0xE000,0x0000,0x0000,0x0000,0x0000,
	0x0078,0x1F81,0xF800,0x0001,0xFF80,0x0078,0x07F8,0x7801,0xE01F,0xF807,0x8000,0x0000,0x0000,0x0000,0x0000,
	0x0078,0x0000,0x0000,0x0000,0x0000,0x0078,0x0000,0x0001,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x001F,0x8000,0x0000,0x0000,0x0000,0x001F,0x8000,0x0000,0x7E00,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x781E,0x01E0,0x0000,0x1FF9,0xE000,0x7FF9,0xF800,0x0007,0x8007,0x8000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF87F,0x87F8,0x0001,0xFFFF,0xE007,0xFFE7,0xFE00,0x001F,0xE01E,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0007,0xF9FF,0x9FF8,0x0007,0xE01F,0xE01F,0x879E,0x7E00,0x007F,0xFFF8,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x001F,0x9FFF,0xE078,0x1E78,0x7E00,0x01E0,0x7F80,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x001E,0x7FE7,0xE000,0x79E0,0x7800,0x01FE,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x001E,0x0787,0xE001,0xFFE1,0xE000,0x01FF,0xE000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x001F,0xF81F,0x81F8,0x0007,0x9E07,0xE001,0xFFE7,0x8000,0x079F,0xFE00,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x007F,0xF81F,0x81F8,0x0001,0xF807,0xE001,0xFFFE,0x0000,0x01F9,0xFFE0,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x0001,0xE007,0xE001,0xFFE7,0xF800,0x001F,0x9FF8,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x0007,0xFFFF,0xE001,0xFFE0,0x7E00,0x0001,0xF9FE,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xF81F,0x81F8,0x001E,0x0007,0xE001,0xE7E0,0x7E00,0x01FE,0x1E7E,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0001,0xE01F,0xE1E0,0x0078,0x0007,0xE000,0x0780,0x7E00,0x1FFF,0xE078,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0007,0xFE7F,0xE780,0x07FF,0x81FF,0xE007,0xFE00,0x7F80,0x7E07,0xFFE0,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x001E,0x7FE7,0xFE00,0x1E07,0xFF87,0xF81E,0x7F9E,0x7E00,0x7800,0x7F80,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0078,0x1F81,0xF800,0x1E01,0xFE01,0xE078,0x07F8,0x7800,0x1F80,0x1E00,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0078,0x0000,0x0000,0x07E0,0x0000,0x0078,0x0000,0x0000,0x01FE,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x001F,0x8000,0x0000,0x0000,0x0000,0x001F,0x8000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,
	0xC000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000
};

/* About bitmap has 2 blank lines to left and right, and 1 blank line
above and below. */

UWORD chip AboutData[240] =
{	/* Plane 0 */
	0x0000,0x0000,0x0007,
	0x0200,0x0000,0x0007,
	0x1AC0,0x0000,0x0007,
	0x0700,0x0C00,0x0007,
	0x1AC1,0xE600,0x0407,
	0x0203,0xC300,0x0407,
	0x0000,0x0180,0x0407,
	0x0000,0x001F,0xFBE7,
	0x1E00,0x0060,0x1C07,
	0x0000,0x0030,0x6407,
	0x07F8,0x0018,0x0407,
	0x03F0,0x0004,0x0007,
	0x01E0,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0F3B,0x91F3,0xCC47,
	0x10A4,0x9204,0x2A47,
	0x1FA4,0x9277,0xE947,
	0x10A0,0x9214,0x2947,
	0x10A0,0x91F4,0x28C7,
	0x0000,0x0000,0x0007,
	/* Plane 1 */
	0x0000,0x0000,0x0007,
	0x0000,0x3800,0x0007,
	0x0000,0x7C00,0x0007,
	0x0000,0xFE00,0x0007,
	0x0001,0xE700,0x0007,
	0x0003,0xC380,0x00C7,
	0x0007,0x81C0,0x0307,
	0x0000,0x0000,0x0407,
	0x001E,0x0070,0x1C07,
	0x003C,0x0038,0x6407,
	0x0078,0x001C,0x0407,
	0x00F0,0x0006,0x0007,
	0x01E0,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	/* Plane 2 */
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0800,0x0007,
	0x0000,0x0400,0x6007,
	0x0007,0x8200,0x1807,
	0x3C0F,0xFFE0,0x07E7,
	0x1E1F,0xE080,0x1807,
	0x003C,0x1C40,0x6007,
	0x0078,0x03A0,0x0007,
	0x00F0,0x0078,0x0007,
	0x01E0,0x000F,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	0x0000,0x0000,0x0007,
	/* Plane 3 */
	0x0000,0x0000,0x0000,
	0x0000,0x3800,0x0000,
	0x0000,0x7800,0x0000,
	0x0000,0xF000,0x0000,
	0x0001,0xE000,0x0400,
	0x0003,0xC000,0x64C0,
	0x0007,0x8000,0x1F00,
	0x3C00,0x0000,0x03E0,
	0x1E1E,0x0000,0x1F00,
	0x0F3C,0x0000,0x64C0,
	0x07F8,0x0000,0x0400,
	0x03F0,0x0000,0x0000,
	0x01E0,0x0000,0x0000,
	0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000,
	0x0000,0x0000,0x0000
};

UWORD chip BackgroundData[9840] =
{	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C0,0x3CF0,0x0F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F0E,0x0FC1,0xC3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C15,0x0302,0x00C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE015,0x0002,0xC01E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8015,0x0002,0x4007,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x0C11,0x0381,0xC0C1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0x1200,0x0100,0x0120,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C0,0x1E00,0x0100,0x01E0,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0x1206,0x0101,0x8120,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x121F,0x8387,0xE121,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8079,0xE01E,0x7807,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,
        0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,0xE078,0x781E,0x1E07,0x8781,0xE1E0,0x7878,0x1E1E,0x0787,0x81E1,
	0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,
        0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,0x79E3,0x1E78,0xC79E,0x31E7,0x8C79,0xE31E,0x78C7,0x9E31,0xE78C,
	0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
	0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,
        0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,0xF0F0,0x3C3C,0x0F0F,0x03C3,0xC0F0,0xF03C,0x3C0F,0x0F03,0xC3C0,
	0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,
        0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,0xC63C,0xF18F,0x3C63,0xCF18,0xF3C6,0x3CF1,0x8F3C,0x63CF,0x18F3,
        0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,
        0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F,0x1F8F,0xC7E3,0xF1F8,0xFC7E,0x3F1F,0x8FC7,0xE3F1,0xF8FC,0x7E3F
};

// PRIVATE STRUCTURES -----------------------------------------------------

struct Image IsoImage =
{   0, 0,
    11, ISOSQUAREY, 4,
    IsoImageData[0],
    0xff, 0x0,
    NULL
};
struct Image Image =
{   0, 0,
    SQUAREX, SQUAREY, 4,
    ImageData[0],
    0xff, 0x0,
    NULL
};
struct Image Logo =
{   0, 0,
    229, 54, 4,
    LogoData,
    0xff,0x0,
    NULL
};
struct Image About =
{   0, 0,
    45, 20, 4,
    AboutData,
    0xff, 0x0,
    NULL
};
struct Image Background =
{   0, 0,
    640, 245, 1,
    BackgroundData,
    1, 0, // the 0 of PlaneOnOff is replaced with 8, 10, 12 or 14.
    NULL
};
MODULE struct EasyStruct EasyStruct =
{   sizeof(struct EasyStruct),
    0,
    TITLEBAR,
    "Fieldset/highscores have been modified.",
    "Continue|Cancel"
};
struct
{   WORD x, y;
    STRPTR text;
} about[ABOUTLINES + 1] =
{   {80,  27, "Worm Wars 6.9 for Amiga"    },
    {80,  35, "Friday 8 February 2002"     },
    {80,  43, " 2002 Amigan Software"     },
    {16,  59, "By James R. Jacobs"         },
    {16,  75, "Fieldset size:        bytes"},
    {16,  91, "Kickstart:"                 },
    {16,  99, "Workbench:"                 }
};
struct
{   UBYTE scancode;
    BYTE  player, deltax, deltay, special;
    BOOL  down;
} key[NUMKEYS + 1] =
{   {Q,               0, -1, -1, MOVE,     FALSE},
    {W,               0,  0, -1, MOVE,     FALSE},
    {E,               0,  1, -1, MOVE,     FALSE},
    {A,               0, -1,  0, MOVE,     FALSE},
    {S,               0,  0,  1, MOVE,     FALSE},
    {D,               0,  1,  0, MOVE,     FALSE},
    {Z,               0, -1,  1, MOVE,     FALSE},
    {KEY_X,           0,  1,  1, MOVE,     FALSE},
    {C,               0,  1,  1, MOVE,     FALSE},
    {NUMERICSEVEN,    1, -1, -1, MOVE,     FALSE},
    {NUMERICEIGHT,    1,  0, -1, MOVE,     FALSE},
    {NUMERICNINE,     1,  1, -1, MOVE,     FALSE},
    {NUMERICFOUR,     1, -1,  0, MOVE,     FALSE},
    {NUMERICFIVE,     1,  0,  1, MOVE,     FALSE},
    {NUMERICSIX,      1,  1,  0, MOVE,     FALSE},
    {NUMERICONE,      1, -1,  1, MOVE,     FALSE},
    {NUMERICTWO,      1,  0,  1, MOVE,     FALSE},
    {NUMERICTHREE,    1,  1,  1, MOVE,     FALSE},
    {UP,              1,  0, -1, ONEHUMAN, FALSE},
    {DOWN,            1,  0,  1, ONEHUMAN, FALSE},
    {RIGHT,           1,  1,  0, ONEHUMAN, FALSE},
    {LEFT,            1, -1,  0, ONEHUMAN, FALSE},
    {SPACEBAR,        0,  0,  0, AMMO,     FALSE},
    {NUMERICZERO,     1,  0,  0, AMMO,     FALSE},
    {ENTER,           1,  0,  0, AMMO,     FALSE},
    {HELP,            0,  0,  0, TRAINER,  FALSE},
    {NUMERICSLASH,    0,  0,  0, TRAINER,  FALSE},
    {NUMERICASTERISK, 0,  0,  0, TRAINER,  FALSE},
    {NUMERICPLUS,     0,  0,  0, TRAINER,  FALSE}
}; /* Never leave unused keys in this structure. */

/* #DEFINES -------------------------------------------------------------- */

#define ID_8SVX  MAKE_ID('8','S','V','X')
#define ID_BODY  MAKE_ID('B','O','D','Y')
#define ID_VHDR  MAKE_ID('V','H','D','R')
#define PALCLOCK 3546895
#define SOFT          32
#define LOUD          64 /* = Unity */

/* PRIVATE STRUCTURES ---------------------------------------------------- */

#define INDEX_ANIMATIONS  21
#define INDEX_CREATEICONS 22

struct NewMenu NewMenu[30 + 1] =
{   { NM_TITLE, "Project",        0 , 0,                    0, 0}, //  0
    {  NM_ITEM, "New",           "N", 0,                    0, 0}, //  1
    {  NM_ITEM, "Open...",       "O", 0,                    0, 0}, //  2
    {  NM_ITEM, "Revert",        "R", 0,                    0, 0}, //  3
    {  NM_ITEM, NM_BARLABEL,      0 , 0,                    0, 0}, //  4
    {  NM_ITEM, "Save",          "S", 0,                    0, 0}, //  5
    {  NM_ITEM, "Save As...",    "A", 0,                    0, 0}, //  6
    {  NM_ITEM, NM_BARLABEL,      0 , 0,                    0, 0}, //  7
    {  NM_ITEM, "Delete...",     "D", 0,                    0, 0}, //  8
    {  NM_ITEM, NM_BARLABEL,      0 , 0,                    0, 0}, //  9
    {  NM_ITEM, "Quit",          "Q", 0,                    0, 0}, // 10
    { NM_TITLE, "Edit",           0 , NM_MENUDISABLED,      0, 0}, // 11
    {  NM_ITEM, "Cut",           "X", 0,                    0, 0}, // 12
    {  NM_ITEM, "Copy",          "C", 0,                    0, 0}, // 13
    {  NM_ITEM, "Paste",         "V", 0,                    0, 0}, // 14
    {  NM_ITEM, NM_BARLABEL,      0 , 0,                    0, 0}, // 15
    {  NM_ITEM, "Erase",         "E", 0,                    0, 0}, // 16
    {  NM_ITEM, "Delete",         0 , 0,                    0, 0}, // 17
    {  NM_ITEM, "Insert",         0 , 0,                    0, 0}, // 18
    {  NM_ITEM, "Append",         0 , 0,                    0, 0}, // 19
    { NM_TITLE, "Settings",       0 , 0,                    0, 0}, // 20
    {  NM_ITEM, "Animations?",   "T", CHECKIT | MENUTOGGLE, 0, 0}, // 21
    {  NM_ITEM, "Create Icons?", "I", CHECKIT | MENUTOGGLE, 0, 0}, // 22
    { NM_TITLE, "Help",           0 , 0,                    0, 0}, // 23
    {  NM_ITEM, "Creatures...",  "1", 0,                    0, 0}, // 24
    {  NM_ITEM, "Objects...",    "2", 0,                    0, 0}, // 25
    {  NM_ITEM, NM_BARLABEL,      0 , 0,                    0, 0}, // 26
    {  NM_ITEM, "Manual...",     "M", 0,                    0, 0}, // 27
    {  NM_ITEM, NM_BARLABEL,      0 , 0,                    0, 0}, // 28
    {  NM_ITEM, "About...",      "?", 0,                    0, 0}, // 29
    {   NM_END, NULL,             0 , 0,                    0, 0}  // 30
};

struct GamePortTrigger Trigger =
{   GPTF_DOWNKEYS,
    65535,
    1, 1
};
struct NewGadget CycleGadget =
{   360, 0,
    128, 13,
    NULL, /* this value gets changed anyway */
    NULL,
    NULL,
    NULL,
    NULL,
    NULL
};
struct NewGadget CheckboxGadget =
{   250, TSOFFSET + 133,
    0, 0,
    "_Isometric 3D?",
    NULL,
    NULL,
    NULL,
    NULL
};
struct NewGadget RandomGadget =
{   250, TSOFFSET + 117,
    0, 0,
    "_Shuffle Levels?",
    NULL,
    NULL,
    NULL,
    NULL
};
struct NewGadget StringGadget =
{   235, 0,
    181, 12,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL
};
struct
{   STRPTR filename;
    BYTE   volume;
    ULONG  length[2], size, speed, bank;
    UBYTE* base;
} samp[SAMPLES + 1] =
{   {   "PROGDIR:fx/dogawakens.8svx", SOFT}, /* FXBORN_DOG */
    {     "PROGDIR:fx/dripborn.8svx", SOFT}, /* FXBORN_DRIP */
    {     "PROGDIR:fx/goatborn.8svx", SOFT}, /* FXBORN_GOAT */
    {"PROGDIR:fx/missileactive.8svx", LOUD}, /* FXBORN_MISSILE */
    {      "PROGDIR:fx/orbborn.8svx", SOFT}, /* FXBORN_ORB */
    {  "PROGDIR:fx/penguinborn.8svx", SOFT}, /* FXBORN_PENGUIN */
    {"PROGDIR:fx/protectorborn.8svx", SOFT}, /* FXBORN_PROTECTOR */
    {         "PROGDIR:fx/thud.8svx", SOFT}, /* FXDEATH_FRAGMENT (thud) */
    {    "PROGDIR:fx/goatdeath.8svx", SOFT}, /* FXDEATH_GOAT */
    {     "PROGDIR:fx/orbdeath.8svx", SOFT}, /* FXDEATH_ORB */
    { "PROGDIR:fx/penguindeath.8svx", SOFT}, /* FXDEATH_PENGUIN */
    {    "PROGDIR:fx/wormdeath.8svx", LOUD}, /* FXDEATH_WORM */
    { "PROGDIR:fx/timebombtick.8svx", LOUD}, /* FXDO_BOMB (tick) */
    {    "PROGDIR:fx/enclosure.8svx", LOUD}, /* FXDO_ENCLOSE */
    {     "PROGDIR:fx/goatfire.8svx", SOFT}, /* FXDO_GOAT (fire) */
    {         "PROGDIR:fx/jump.8svx", SOFT}, /* FXDO_JUMP */
    {     "PROGDIR:fx/orbsplit.8svx", SOFT}, /* FXDO_ORB (split) */
    {      "PROGDIR:fx/getammo.8svx", LOUD}, /* FXGET_AMMO */
    {      "PROGDIR:fx/cyclone.8svx", LOUD}, /* FXGET_CYCLONE */
    {           "PROGDIR:fx/fx.8svx", SOFT}, /* FXGET_DRIP */
    {    "PROGDIR:fx/getgrower.8svx", SOFT}, /* FXGET_GROWER */
    {    "PROGDIR:fx/getobject.8svx", SOFT}, /* FXGET_OBJECT */
    {     "PROGDIR:fx/getnitro.8svx", LOUD}, /* FXGET_NITRO */
    {   "PROGDIR:fx/getpowerup.8svx", LOUD}, /* FXGET_POWERUP */
    {      "PROGDIR:fx/explode.8svx", SOFT}, /* FXGET_PULSE (explode) */
    {     "PROGDIR:fx/getskull.8svx", SOFT}, /* FXGET_SKULL */
    {      "PROGDIR:fx/filenew.8svx", LOUD}, /* FXFILENEW */
    {     "PROGDIR:fx/fileopen.8svx", LOUD}, /* FXFILEOPEN */
    {     "PROGDIR:fx/filesave.8svx", LOUD}, /* FXFILESAVE */
    {   "PROGDIR:fx/filesaveas.8svx", LOUD}, /* FXFILESAVEAS */
    {      "PROGDIR:fx/editcut.8svx", LOUD}, /* FXEDITCUT */
    {     "PROGDIR:fx/editcopy.8svx", LOUD}, /* FXEDITCOPY */
    {    "PROGDIR:fx/editpaste.8svx", LOUD}, /* FXEDITPASTE */
    {  "PROGDIR:fx/leveldelete.8svx", LOUD}, /* FXEDITDELETE */
    {       "PROGDIR:fx/amigan.8svx", SOFT}, /* FXHELP */
    {        "PROGDIR:fx/shoot.8svx", SOFT}, /* FXUSE_AMMO */
    {    "PROGDIR:fx/usearmour.8svx", SOFT}, /* FXUSE_ARMOUR */
    {    "PROGDIR:fx/bombblast.8svx", SOFT}, /* FXUSE_BOMB */
    {  "PROGDIR:fx/useteleport.8svx", SOFT}, /* FXUSE_TELEPORT */
    {    "PROGDIR:fx/usetongue.8svx", SOFT}, /* FXBORN_BIRD */
    {            "PROGDIR:fx/C.8svx", LOUD}, /* FX_C */
    {            "PROGDIR:fx/O.8svx", LOUD}, /* FX_O */
    {            "PROGDIR:fx/M.8svx", LOUD}, /* FX_M */
    {            "PROGDIR:fx/P.8svx", LOUD}, /* FX_P */
    {            "PROGDIR:fx/L.8svx", LOUD}, /* FX_L */
    {            "PROGDIR:fx/E.8svx", LOUD}, /* FX_E */
    {            "PROGDIR:fx/T.8svx", LOUD}, /* FX_T */
    {        "PROGDIR:fx/green.8svx", SOFT}, /* FXPAIN */
    {          "PROGDIR:fx/red.8svx", SOFT},
    {         "PROGDIR:fx/blue.8svx", SOFT},
    {       "PROGDIR:fx/yellow.8svx", SOFT},
    {    "PROGDIR:fx/highscore.8svx", SOFT}, /* FXAPPLAUSE (after each new hiscore) */
    {       "PROGDIR:fx/defeat.8svx", LOUD}, /* FXGAMEOVER (if all worms are dead) */
    {      "PROGDIR:fx/victory.8svx", SOFT}, /* FXCELEBRATE (if game succeeded) */
    {        "PROGDIR:fx/click.8svx", SOFT}, /* FXCLICK (rundown, keypresses) */
    {  "PROGDIR:fx/titlescreen.8svx", SOFT}, /* FXLAUNCH (title screen) */
    {   "PROGDIR:fx/endoflevel.8svx", LOUD}, /* FXRIFF (after each rundown) */
    {    "PROGDIR:fx/timealert.8svx", SOFT}  /* FXSIREN (out of time) */
};

/* ARRAYS -------------------------------------------------------------- */

MODULE STRPTR CycleText[] =
{   "Worm _1:",
    "Worm _2:",
    "Worm _3:",
    "Worm _4:"
};
MODULE UBYTE* CycleOptions[4][6] =
{ { (UBYTE *) "None",
    (UBYTE *) "Amiga",
    (UBYTE *) "Joystick 3",
    (UBYTE *) "Gamepad 3",
    (UBYTE *) "Lt. Kybd",
    NULL
  },
  { (UBYTE *) "None",
    (UBYTE *) "Amiga",
    (UBYTE *) "Joystick 4",
    (UBYTE *) "Gamepad 4",
    (UBYTE *) "Rt. Kybd",
    NULL
  },
  { (UBYTE *) "None",
    (UBYTE *) "Amiga",
    (UBYTE *) "Joystick 2",
    (UBYTE *) "Gamepad 2",
    NULL,
    NULL
  },
  { (UBYTE *) "None",
    (UBYTE *) "Amiga",
    (UBYTE *) "Joystick 1",
    (UBYTE *) "Gamepad 1",
    NULL,
    NULL
} };

MODULE STRPTR sfxerror[] =
{   "No errors.",
    "Can't open file!",
    "Can't read file!",
    "Not an IFF 8SVX; too short!",
    "Not an IFF FORM!",
    "No memory for read!",
    "Read error!",
    "Malformed IFF; too short!",
    "Not an IFF 8SVX!",
    "No chip memory!"
};

/* PUBLIC STRUCTURES ----------------------------------------------------- */

struct Chunk
{   LONG          ckID;
    LONG          ckSize;
    LONG          ckType;
    void*         ckData;
    struct Chunk* ckNext;
};

/* TYPEDEFS --------------------------------------------------------------- */

typedef LONG Fixed;          /* A fixed-point value, 16 bits to the left
                                of the point and 16 to the right. A Fixed
                                is a number of 2**16ths, ie. 65536ths. */
typedef struct
{   ULONG oneShotHiSamples,  /* # samples in the high octave 1-shot part */
          repeatHiSamples,   /* # samples in the high octave repeat part */
          samplesPerHiCycle; /* # samples/cycle in high octave, else 0 */
    UWORD samplesPerSec;     /* data sampling rate */
    UBYTE ctOctave,          /* # of octaves of waveforms */
          sCompression;      /* data compression technique used */
    Fixed volume;            /* playback nominal volume from 0 to Unity
                                (full volume). Map this value into the
                                output hardware's dynamic range (0-64). */
} Voice8Header;

/* Must have blank line at EOF. */
